@@ -25,14 +25,13 @@
 #include <stdlib.h>
 #include <gdk/gdkkeysyms.h>
 #include <sys/types.h>
+#include <glib/gi18n.h>
 
 #include "kazehakase.h"
-#include "intl.h"
 #include "utils/utils.h"
 #include "gobject-utils.h"
-#include "gtk24backports.h"
-#include "kz-mozembed.h"
 #include "kz-bookmark.h"
+#include "kz-smart-bookmark.h"
 #include "kz-actions.h"
 
 enum {
@@ -125,9 +124,10 @@ kz_location_entry_action_class_init (KzLocationEntryActionClass *klass)
 static void
 kz_location_entry_action_init (KzLocationEntryAction *action)
 {
-	action->kz = NULL;
-	action->bookmark = NULL;
-	action->activating = FALSE;
+	action->kz            = NULL;
+	action->bookmark      = NULL;
+	action->history       = NULL;
+	action->activating    = FALSE;
 	action->synchronizing = FALSE;
 }
 
@@ -144,11 +144,18 @@ kz_location_entry_action_dispose (GObject *obj)
 		action->kz = NULL;
 	}
 
+	if (action->history)
+	{
+		g_object_unref(action->history);
+		action->history = NULL;
+	}
+
 	if (action->bookmark)
 	{
 		g_object_unref(action->bookmark);
 		action->bookmark = NULL;
 	}
+
 	if (G_OBJECT_CLASS(parent_class)->dispose)
 		G_OBJECT_CLASS(parent_class)->dispose(obj);
 }
@@ -222,7 +229,7 @@ kz_location_entry_action_activate (GtkAction *action)
 
 
 	uri = kz_entry_action_get_text(KZ_ENTRY_ACTION(action));
-	smart_uri = kz_bookmark_get_smart_uri(entry_action->bookmark, uri);
+	smart_uri = kz_smart_bookmark_get_smart_uri(KZ_SMART_BOOKMARK(entry_action->bookmark), uri);
 
 	gdk_window_get_pointer(NULL, &x, &y, &state);
 	
@@ -247,6 +254,11 @@ kz_location_entry_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 	entry = kz_entry_action_get_entry_widget(KZ_ENTRY_ACTION(action), proxy);
 	if (entry)
 	{
+		gboolean autocompletion = FALSE;
+		KZ_CONF_GET("Global", "use_auto_completion", autocompletion, BOOL);
+		if(autocompletion)
+			kz_history_set_completion (KZ_HISTORY_ACTION(action), entry);
+
 		g_signal_connect(G_OBJECT(entry), "key-press-event",
 				 G_CALLBACK(cb_entry_key_press), action);
 		g_signal_connect(G_OBJECT(entry), "populate-popup",
@@ -294,14 +306,13 @@ kz_location_entry_action_new (KzWindow *kz)
 {
 	KzLocationEntryAction *action;
 
-	action = KZ_LOCATION_ENTRY_ACTION(
-			g_object_new(KZ_TYPE_LOCATION_ENTRY_ACTION,
-				     "name",        "LocationEntry",
-				     "label",       _("Location Entry"),
-				     "tooltip",     NULL,
-				     "stock_id",    GTK_STOCK_NEW,
-				     "kz-window",   kz,
-				     NULL));
+	action = g_object_new(KZ_TYPE_LOCATION_ENTRY_ACTION,
+			      "name",        "LocationEntry",
+			      "label",       _("Location Entry"),
+			      "tooltip",     NULL,
+			      "stock_id",    GTK_STOCK_NEW,
+			      "kz-window",   kz,
+			      NULL);
 	kz_location_entry_action_restore_history(action);
 
 	return action;
@@ -327,8 +338,8 @@ kz_location_entry_action_store_history (KzLocationEntryAction *action)
 	}
 	g_list_free(list);
 
-	list = (GList*)kz_history_action_get_history(KZ_HISTORY_ACTION(action));
-	for (node = list; node; node = g_list_next((GList *) node))
+	list = kz_history_action_get_history(KZ_HISTORY_ACTION(action));
+	for (node = list; node; node = g_list_next(node))
 	{
 		const gchar *uri = node->data;
 		gchar key[256];
@@ -340,6 +351,9 @@ kz_location_entry_action_store_history (KzLocationEntryAction *action)
 		KZ_CONF_SET_STR("LocationEntry", key, uri);
 		i++;
 	}
+	g_list_foreach(list, (GFunc) g_free, NULL);
+	g_list_free(list);
+
 }
 
 
@@ -437,7 +451,8 @@ cb_entry_key_press (GtkWidget *widget, GdkEventKey *event,
 		KZ_CONF_GET("Global", "entry_open_in_new_tab", new_tab, BOOL);
 
 		uri = kz_entry_action_get_text(KZ_ENTRY_ACTION(action));
-		smart_uri = kz_bookmark_get_smart_uri(KZ_LOCATION_ENTRY_ACTION(action)->bookmark, uri);
+		smart_uri = kz_smart_bookmark_get_smart_uri(
+				KZ_SMART_BOOKMARK(KZ_LOCATION_ENTRY_ACTION(action)->bookmark), uri);
 		if (new_tab)
 			kz_window_load_url(action->kz, smart_uri);
 		else 
