@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-actions-bookmark.c,v 1.27 2004/10/15 13:05:02 ikezoe Exp $
+ *  $Id: kz-actions-bookmark.c,v 1.30 2004/11/24 11:08:09 ikezoe Exp $
  */
 
 #include "kz-actions-bookmark.h"
@@ -26,6 +26,7 @@
 #include "kz-icons.h"
 #include "kz-bookmark-edit-win.h"
 #include "kz-smart-bookmark.h"
+#include "kz-bookmark-file.h"
 
 static GtkActionEntry kz_actions_bookmark[];
 static const gint     kz_actions_bookmark_len;
@@ -79,6 +80,7 @@ static void
 insert_bookmark_item (KzBookmarkEditor *editor, KzBookmark *bookmark)
 {
 	KzBookmark *parent, *sibling = NULL;
+	KzBookmark *file;
 	GList *list;
 
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
@@ -100,6 +102,19 @@ insert_bookmark_item (KzBookmarkEditor *editor, KzBookmark *bookmark)
 
 	kz_bookmark_insert_before(parent, bookmark, sibling);
 
+	if (KZ_IS_BOOKMARK_FILE(parent))
+		file = parent;
+	else
+		file = kz_bookmark_get_parent_file(parent);
+
+	if (kz_bookmark_file_has_xmlrpc(KZ_BOOKMARK_FILE(file)))
+	{
+		kz_bookmark_file_xmlrpc_insert(KZ_BOOKMARK_FILE(file),
+					       parent,
+					       sibling,
+					       bookmark);
+	}
+
 	g_list_free(list);
 	/* focus to new bookmark item */
 	kz_bookmark_editor_bookmarks_view_select(editor, bookmark);
@@ -143,7 +158,7 @@ act_insert_remote_bookmark (GtkAction *action, KzBookmarkEditor *editor)
 	g_return_if_fail(GTK_IS_ACTION(action));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 
-	file = kz_bookmark_file_new(NULL, NULL, NULL);
+	file = KZ_BOOKMARK(kz_bookmark_file_new(NULL, NULL, NULL));
 	kz_bookmark_set_title(file, _("New Remote Bookmark"));
 	insert_bookmark_item(editor, file);
 	g_object_unref(G_OBJECT(file));
@@ -200,9 +215,22 @@ act_remove_selected_item (GtkAction *action, KzBookmarkEditor *editor)
 
 	for (node = list; node; node = g_list_next(node))
 	{
+		KzBookmark *file;
+
 		bookmark = node->data;
 		if (!KZ_IS_BOOKMARK(bookmark)) continue;
 		kz_bookmark_remove(parent, bookmark);
+		
+		if (KZ_IS_BOOKMARK_FILE(parent))
+			file = parent;
+		else
+			file = kz_bookmark_get_parent_file(parent);
+
+		if (kz_bookmark_file_has_xmlrpc(KZ_BOOKMARK_FILE(file)))
+		{
+			kz_bookmark_file_xmlrpc_remove(KZ_BOOKMARK_FILE(file),
+						       bookmark);
+		}
 	}
 
 	g_list_free(list);
