@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-edit.c,v 1.26 2004/10/15 13:05:02 ikezoe Exp $
+ *  $Id: kz-bookmark-edit.c,v 1.32 2004/11/22 01:08:41 ikezoe Exp $
  */
 
 #include <glib/gi18n.h>
@@ -27,6 +27,7 @@
 #include "gobject-utils.h"
 #include "gtk-utils.h"
 #include "kz-thumbnail.h"
+#include "kz-bookmark-file.h"
 
 #define REGEX_ENTRY_WIDTH 100
 #define URI_ENTRY_WIDTH 150
@@ -63,19 +64,25 @@ static void kz_bookmark_edit_sync_properties (KzBookmarkEdit *edit,
 static void kz_bookmark_edit_set_smart_list  (KzBookmarkEdit *edit,
 					      const GList *smart_list);
 
-static void cb_bookmark_notify          (GObject *object,
-					 GParamSpec *pspec,
-					 KzBookmarkEdit *edit);
-static void cb_title_entry_changed      (GtkEditable    *editable,
-					 KzBookmarkEdit *edit);
-static void cb_uri_entry_changed        (GtkEditable    *editable,
-					 KzBookmarkEdit *edit);
-static void cb_location_entry_changed   (GtkEditable    *editable,
-					 KzBookmarkEdit *edit);
-static void cb_interval_value_changed   (GtkSpinButton  *button,
-					 KzBookmarkEdit *edit);
-static void cb_description_changed      (GtkTextBuffer  *textbuf,
-					 KzBookmarkEdit *edit);
+static void cb_bookmark_notify           (GObject *object,
+					  GParamSpec *pspec,
+					  KzBookmarkEdit *edit);
+static void cb_title_entry_changed       (GtkEditable    *editable,
+					  KzBookmarkEdit *edit);
+static void cb_uri_entry_changed         (GtkEditable    *editable,
+					  KzBookmarkEdit *edit);
+static void cb_location_entry_changed    (GtkEditable    *editable,
+					  KzBookmarkEdit *edit);
+static void cb_interval_value_changed    (GtkSpinButton  *button,
+					  KzBookmarkEdit *edit);
+static void cb_description_changed       (GtkTextBuffer  *textbuf,
+					  KzBookmarkEdit *edit);
+static void cb_xmlrpc_entry_changed      (GtkEditable    *editable,
+					  KzBookmarkEdit *edit);
+static void cb_xmlrpc_user_entry_changed (GtkEditable    *editable,
+					  KzBookmarkEdit *edit);
+static void cb_xmlrpc_pass_entry_changed (GtkEditable    *editable,
+					  KzBookmarkEdit *edit);
 
 static GtkWidget *create_widget_for_smart_property (KzBookmarkEdit *edit);
 
@@ -111,11 +118,8 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 	GtkWidget *interval_label, *interval_spin;
 	GtkWidget *memo_label, *textview;
 	GtkWidget *thumbnail;
-#if 0
-	GtkWidget *xmlrpc, *xmlrpc_user, *xmlrpc_pass;
-	GtkWidget *check, *frame, *vbox;
-	GtkWidget *label, *entry;
-#endif
+	GtkWidget *xmlrpc_label, *xmlrpc_user_label, *xmlrpc_pass_label;
+	GtkWidget *xmlrpc_entry, *xmlrpc_user_entry, *xmlrpc_pass_entry;
 	GtkTextBuffer *textbuf;
 
 	edit->smart = g_new0(KzSmartBookmarkEdit, 1);
@@ -179,7 +183,6 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 
 	location_label = gtk_label_new(_("Location:"));
 	gtk_box_pack_start(GTK_BOX(hbox), location_label, FALSE, FALSE, 0);
-	gtk_widget_show(location_label);
 
 	location_entry = gtk_entry_new();
 	gtk_table_attach(GTK_TABLE(table), location_entry,
@@ -188,7 +191,6 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 2, 2);       /* padding x, y  */
 	g_signal_connect(G_OBJECT(location_entry), "changed",
 			 G_CALLBACK(cb_location_entry_changed), edit);
-	gtk_widget_show(location_entry);
 
 	/* Update interval */
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -200,26 +202,13 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 
 	interval_label = gtk_label_new(_("Update interval (min):"));
 	gtk_box_pack_start(GTK_BOX(hbox), interval_label, FALSE, FALSE, 0);
-	gtk_widget_show(interval_label);
 
 	interval_spin = gtk_spin_button_new_with_range(0, 60 * 24 * 7, 1);
 	gtk_box_pack_start(GTK_BOX(hbox), interval_spin, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(interval_spin), "value-changed",
 			 G_CALLBACK(cb_interval_value_changed), edit);
-	gtk_widget_show(interval_spin);
-#if 0
+#if 1
 	/* XML-RPC interface for shared bookmark */
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_table_attach(GTK_TABLE(table), hbox,
-			 0, 1, 4, 5,  /* xpos, ypos */
-			 GTK_FILL, 0,
-			 2, 2);       /* padding x, y  */
-	gtk_widget_show(hbox);
-
-	label = gtk_label_new(_("Shared bookmark"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
-
 	/* Interface address */
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox,
@@ -228,18 +217,16 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 2, 2);       /* padding x, y  */
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("Interface:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	xmlrpc_label = gtk_label_new(_("Interface:"));
+	gtk_box_pack_start(GTK_BOX(hbox), xmlrpc_label, FALSE, FALSE, 0);
 
-	entry = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), entry,
+	xmlrpc_entry = gtk_entry_new();
+	gtk_table_attach(GTK_TABLE(table), xmlrpc_entry,
 			 1, 2, 4, 5,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(entry), "changed",
-			 G_CALLBACK(cb_location_entry_changed), edit);
-	gtk_widget_show(entry);
+	g_signal_connect(G_OBJECT(xmlrpc_entry), "changed",
+			 G_CALLBACK(cb_xmlrpc_entry_changed), edit);
 	
 	/* User name */
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -249,18 +236,17 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 2, 2);       /* padding x, y  */
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("User name:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	xmlrpc_user_label = gtk_label_new(_("User name:"));
+	gtk_box_pack_start(GTK_BOX(hbox), xmlrpc_user_label, FALSE, FALSE, 0);
 
-	entry = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), entry,
+	xmlrpc_user_entry = gtk_entry_new();
+	gtk_table_attach(GTK_TABLE(table), xmlrpc_user_entry,
 			 1, 2, 5, 6,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(entry), "changed",
-			 G_CALLBACK(cb_location_entry_changed), edit);
-	gtk_widget_show(entry);
+	g_signal_connect(G_OBJECT(xmlrpc_user_entry), "changed",
+			 G_CALLBACK(cb_xmlrpc_user_entry_changed), edit);
+	
 	/* Password */
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox,
@@ -269,18 +255,17 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 2, 2);       /* padding x, y  */
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("Password:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	xmlrpc_pass_label = gtk_label_new(_("Password:"));
+	gtk_box_pack_start(GTK_BOX(hbox), xmlrpc_pass_label, FALSE, FALSE, 0);
 
-	entry = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), entry,
+	xmlrpc_pass_entry = gtk_entry_new();
+	gtk_entry_set_visibility(GTK_ENTRY(xmlrpc_pass_entry), FALSE);
+	gtk_table_attach(GTK_TABLE(table), xmlrpc_pass_entry,
 			 1, 2, 6, 7,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(entry), "changed",
-			 G_CALLBACK(cb_location_entry_changed), edit);
-	gtk_widget_show(entry);
+	g_signal_connect(G_OBJECT(xmlrpc_pass_entry), "changed",
+			 G_CALLBACK(cb_xmlrpc_pass_entry_changed), edit);
 #endif
 	/* Memo */
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -330,20 +315,27 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 	gtk_widget_show(thumbnail);
 
 	/* initialize */
-	edit->title_label    = title_label;
-	edit->title_entry    = title_entry;
-	edit->uri_label      = uri_label;
-	edit->uri_entry      = uri_entry;
-	edit->location_label = location_label;
-	edit->location_entry = location_entry;
-	edit->interval_label = interval_label;
-	edit->interval_spin  = interval_spin;
-	edit->memo_label     = memo_label;
-	edit->memo_textview  = textview;
-	edit->memo_scrwin    = scrwin;
-	edit->bookmark       = NULL;
-	edit->thumbnail      = thumbnail;
-	edit->changing       = FALSE;
+	edit->title_label       = title_label;
+	edit->title_entry       = title_entry;
+	edit->uri_label         = uri_label;
+	edit->uri_entry         = uri_entry;
+	edit->location_label    = location_label;
+	edit->location_entry    = location_entry;
+	edit->interval_label    = interval_label;
+	edit->interval_spin     = interval_spin;
+	edit->memo_label        = memo_label;
+	edit->memo_textview     = textview;
+	edit->memo_scrwin       = scrwin;
+	edit->xmlrpc_label      = xmlrpc_label;
+	edit->xmlrpc_user_label = xmlrpc_user_label;
+	edit->xmlrpc_pass_label = xmlrpc_pass_label;
+	edit->xmlrpc_entry      = xmlrpc_entry;
+	edit->xmlrpc_user_entry = xmlrpc_user_entry;
+	edit->xmlrpc_pass_entry = xmlrpc_pass_entry;
+
+	edit->bookmark          = NULL;
+	edit->thumbnail         = thumbnail;
+	edit->changing          = FALSE;
 }
 
 
@@ -383,7 +375,7 @@ kz_bookmark_edit_new (void)
 {
 	KzBookmarkEdit *edit;
 
-	edit = KZ_BOOKMARK_EDIT(g_object_new(KZ_TYPE_BOOKMARK_EDIT, NULL));
+	edit = g_object_new(KZ_TYPE_BOOKMARK_EDIT, NULL);
 
 	return GTK_WIDGET(edit);
 }
@@ -427,9 +419,12 @@ kz_bookmark_edit_clear (KzBookmarkEdit *edit)
 	}
 	edit->bookmark = NULL;
 
-	gtk_entry_set_text(GTK_ENTRY(edit->title_entry),    "\0");
-	gtk_entry_set_text(GTK_ENTRY(edit->uri_entry),      "\0");
-	gtk_entry_set_text(GTK_ENTRY(edit->location_entry), "\0");
+	gtk_entry_set_text(GTK_ENTRY(edit->title_entry),       "\0");
+	gtk_entry_set_text(GTK_ENTRY(edit->uri_entry),         "\0");
+	gtk_entry_set_text(GTK_ENTRY(edit->location_entry),    "\0");
+	gtk_entry_set_text(GTK_ENTRY(edit->xmlrpc_entry),      "\0");
+	gtk_entry_set_text(GTK_ENTRY(edit->xmlrpc_user_entry), "\0");
+	gtk_entry_set_text(GTK_ENTRY(edit->xmlrpc_pass_entry), "\0");
 	adj = gtk_spin_button_get_adjustment
 		(GTK_SPIN_BUTTON(edit->interval_spin));
 	gtk_adjustment_set_value(adj, 0.0);
@@ -469,7 +464,7 @@ kz_bookmark_edit_set_sensitive (KzBookmarkEdit *edit)
 	{
 		can_edit_uri = FALSE;
 	}
-	else if (edit->bookmark && kz_bookmark_is_file(edit->bookmark))
+	if (edit->bookmark && KZ_IS_BOOKMARK_FILE(edit->bookmark))
 	{
 		can_edit_location = TRUE;
 		can_edit_interval = TRUE;
@@ -486,7 +481,7 @@ kz_bookmark_edit_set_sensitive (KzBookmarkEdit *edit)
 				   can_edit_desc);
 
 	/* set visible */
-	if (edit->bookmark && kz_bookmark_is_file(edit->bookmark))
+	if (edit->bookmark && KZ_IS_BOOKMARK_FILE(edit->bookmark))
 	{
 		gtk_widget_hide(edit->uri_label);
 		gtk_widget_hide(edit->uri_entry);
@@ -497,6 +492,13 @@ kz_bookmark_edit_set_sensitive (KzBookmarkEdit *edit)
 		gtk_widget_show(edit->location_entry);
 		gtk_widget_show(edit->interval_label);
 		gtk_widget_show(edit->interval_spin);
+
+		gtk_widget_show(edit->xmlrpc_entry);
+		gtk_widget_show(edit->xmlrpc_user_entry);
+		gtk_widget_show(edit->xmlrpc_pass_entry);
+		gtk_widget_show(edit->xmlrpc_label);
+		gtk_widget_show(edit->xmlrpc_user_label);
+		gtk_widget_show(edit->xmlrpc_pass_label);
 	}
 	else
 	{
@@ -530,6 +532,13 @@ kz_bookmark_edit_set_sensitive (KzBookmarkEdit *edit)
 		gtk_widget_hide(edit->location_entry);
 		gtk_widget_hide(edit->interval_label);
 		gtk_widget_hide(edit->interval_spin);
+		
+		gtk_widget_hide(edit->xmlrpc_entry);
+		gtk_widget_hide(edit->xmlrpc_user_entry);
+		gtk_widget_hide(edit->xmlrpc_pass_entry);
+		gtk_widget_hide(edit->xmlrpc_label);
+		gtk_widget_hide(edit->xmlrpc_user_label);
+		gtk_widget_hide(edit->xmlrpc_pass_label);
 	}
 }
 
@@ -539,8 +548,8 @@ kz_bookmark_edit_sync_properties (KzBookmarkEdit *edit, KzBookmark *bookmark)
 {
 	GtkTextBuffer *buffer;
 	GtkAdjustment *adj;
-	const gchar *title, *uri, *location, *desc;
-	guint interval;
+	const gchar *title, *uri, *location = NULL, *desc;
+	guint interval = 0;
 
 	edit->changing = TRUE;
 
@@ -549,8 +558,11 @@ kz_bookmark_edit_sync_properties (KzBookmarkEdit *edit, KzBookmark *bookmark)
 
 	title    = kz_bookmark_get_title(bookmark);
 	uri      = kz_bookmark_get_link(bookmark);
-	location = kz_bookmark_get_location(bookmark);
-	interval = kz_bookmark_get_interval(bookmark);
+	if (KZ_IS_BOOKMARK_FILE(bookmark))
+	{
+		location = kz_bookmark_file_get_location(KZ_BOOKMARK_FILE(bookmark));
+		interval = kz_bookmark_file_get_interval(KZ_BOOKMARK_FILE(bookmark));
+	}
 	desc     = kz_bookmark_get_description(bookmark);
 
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(edit->memo_textview));
@@ -591,6 +603,22 @@ kz_bookmark_edit_sync_properties (KzBookmarkEdit *edit, KzBookmark *bookmark)
 		kz_bookmark_edit_set_smart_list(edit, smart_list);
 	}
 
+	/* for XML-RPC interface */
+	if (KZ_IS_BOOKMARK_FILE(bookmark))
+	{
+		const gchar *xmlrpc, *xmlrpc_pass, *xmlrpc_user;
+
+		xmlrpc      = kz_bookmark_file_get_xmlrpc(KZ_BOOKMARK_FILE(bookmark));
+		xmlrpc_user = kz_bookmark_file_get_xmlrpc_user(KZ_BOOKMARK_FILE(bookmark));
+		xmlrpc_pass = kz_bookmark_file_get_xmlrpc_pass(KZ_BOOKMARK_FILE(bookmark));
+		if (xmlrpc)
+			gtk_entry_set_text(GTK_ENTRY(edit->xmlrpc_entry), xmlrpc);
+		if (xmlrpc_user)
+			gtk_entry_set_text(GTK_ENTRY(edit->xmlrpc_user_entry), xmlrpc_user);
+		if (xmlrpc_pass)
+			gtk_entry_set_text(GTK_ENTRY(edit->xmlrpc_pass_entry), xmlrpc_pass);
+	}
+
 	kz_bookmark_edit_set_sensitive(edit);
 
 	edit->changing = FALSE;
@@ -1085,9 +1113,10 @@ cb_location_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
 
 	if (edit->changing) return;
 	if (!edit->bookmark) return;
+	if (!KZ_IS_BOOKMARK_FILE(edit->bookmark)) return;
 
         uri = gtk_entry_get_text(GTK_ENTRY(editable));
-	kz_bookmark_set_location(edit->bookmark, uri);
+	kz_bookmark_file_set_location(KZ_BOOKMARK_FILE(edit->bookmark), uri);
 }
 
 
@@ -1099,12 +1128,12 @@ cb_interval_value_changed (GtkSpinButton *button, KzBookmarkEdit *edit)
 
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
-	if (!KZ_IS_BOOKMARK(edit->bookmark)) return;
+	if (!KZ_IS_BOOKMARK_FILE(edit->bookmark)) return;
 
 	adj = gtk_spin_button_get_adjustment
 		(GTK_SPIN_BUTTON(edit->interval_spin));
 	interval = gtk_adjustment_get_value(adj);
-	kz_bookmark_set_interval(edit->bookmark, interval);
+	kz_bookmark_file_set_interval(KZ_BOOKMARK_FILE(edit->bookmark), interval);
 }
 
 
@@ -1131,3 +1160,52 @@ cb_description_changed (GtkTextBuffer *textbuf, KzBookmarkEdit *edit)
 
 	g_free(desc);
 }
+
+static void
+cb_xmlrpc_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
+{
+	const gchar *xmlrpc;
+
+	g_return_if_fail(GTK_IS_EDITABLE(editable));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
+
+	if (edit->changing) return;
+	if (!edit->bookmark) return;
+	if (!KZ_IS_BOOKMARK_FILE(edit->bookmark)) return;
+
+        xmlrpc = gtk_entry_get_text(GTK_ENTRY(editable));
+	kz_bookmark_file_set_xmlrpc(KZ_BOOKMARK_FILE(edit->bookmark), xmlrpc);
+}
+
+static void
+cb_xmlrpc_user_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
+{
+	const gchar *user;
+
+	g_return_if_fail(GTK_IS_EDITABLE(editable));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
+
+	if (edit->changing) return;
+	if (!edit->bookmark) return;
+	if (!KZ_IS_BOOKMARK_FILE(edit->bookmark)) return;
+
+        user = gtk_entry_get_text(GTK_ENTRY(editable));
+	kz_bookmark_file_set_xmlrpc_user(KZ_BOOKMARK_FILE(edit->bookmark), user);
+}
+
+static void
+cb_xmlrpc_pass_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
+{
+	const gchar *pass;
+
+	g_return_if_fail(GTK_IS_EDITABLE(editable));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
+
+	if (edit->changing) return;
+	if (!edit->bookmark) return;
+	if (!KZ_IS_BOOKMARK_FILE(edit->bookmark)) return;
+
+        pass = gtk_entry_get_text(GTK_ENTRY(editable));
+	kz_bookmark_file_set_xmlrpc_pass(KZ_BOOKMARK_FILE(edit->bookmark), pass);
+}
+
