@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-item.c,v 1.1 2004/09/30 04:32:11 makeinu Exp $
+ *  $Id: kz-bookmark-item.c,v 1.4 2004/11/22 01:08:41 ikezoe Exp $
  */
 
 #include "kz-bookmark-item.h"
@@ -28,6 +28,7 @@
 
 #include "gobject-utils.h"
 #include "kazehakase.h"
+#include "kz-bookmark-file.h"
 #include "kz-bookmark-menu.h"
 #include "kz-bookmark-editor.h"
 #include "kz-icons.h"
@@ -143,7 +144,7 @@ kz_bookmark_item_class_init (KzBookmarkItemClass *klass)
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_KZ_WINDOW,
-		 g_param_spec_object ("kz_window",
+		 g_param_spec_object ("kz-window",
 				      _("KzWindow"),
 				      _("The KzWindow to add a home button"),
 				      KZ_TYPE_WINDOW,
@@ -174,14 +175,14 @@ kz_bookmark_item_constructor (GType                  type,
 	GtkRcStyle *style;
 	GObject *object;
 	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
-	KzBookmarkState state;
+	KzBookmarkFileState state;
 	gboolean is_file, is_folder;
 
 	object = klass->constructor(type, n_props, props);
 
 	hbox = GTK_BOX(object);
 	menu = KZ_BOOKMARK_ITEM(object);
-	is_file = kz_bookmark_is_file(menu->bookmark);
+	is_file = KZ_IS_BOOKMARK_FILE(menu->bookmark);
 	is_folder = kz_bookmark_is_folder(menu->bookmark);
 	
 	gtk_container_set_border_width(GTK_CONTAINER(menu), 2);
@@ -240,23 +241,25 @@ kz_bookmark_item_constructor (GType                  type,
 	gtk_widget_modify_style (button, style);
 	gtk_rc_style_unref (style);
 
-	g_signal_connect(G_OBJECT(menu->bookmark),
-			 "load_start", 
-			 G_CALLBACK(cb_bookmark_load_start),
-			 menu);
-	g_signal_connect(G_OBJECT(menu->bookmark),
-			 "load_completed", 
-			 G_CALLBACK(cb_bookmark_load_stop),
-			 menu);
-	g_signal_connect(G_OBJECT(menu->bookmark),
-			 "error", 
-			 G_CALLBACK(cb_bookmark_load_error),
-			 menu);
-
-	state = kz_bookmark_get_state(menu->bookmark);
-	if (state == KZ_BOOKMARK_STATE_LOADING)
-		cb_bookmark_load_start(menu->bookmark, menu);
+	if (is_file)
+	{
+		g_signal_connect(G_OBJECT(menu->bookmark),
+				 "load_start", 
+				 G_CALLBACK(cb_bookmark_load_start),
+				 menu);
+		g_signal_connect(G_OBJECT(menu->bookmark),
+				 "load_completed", 
+				 G_CALLBACK(cb_bookmark_load_stop),
+				 menu);
+		g_signal_connect(G_OBJECT(menu->bookmark),
+				 "error", 
+				 G_CALLBACK(cb_bookmark_load_error),
+				 menu);
 
+		state = kz_bookmark_file_get_state(KZ_BOOKMARK_FILE(menu->bookmark));
+		if (state == KZ_BOOKMARK_FILE_STATE_LOADING)
+			cb_bookmark_load_start(menu->bookmark, menu);
+	}
 	/* label */
 	eventbox = kz_input_event_box_new();
 	menu->eventbox = eventbox;
@@ -300,18 +303,21 @@ kz_bookmark_item_dispose (GObject *object)
 
 	if (menu->bookmark)
 	{
-		g_signal_handlers_disconnect_by_func(
-			G_OBJECT(menu->bookmark),
-			cb_bookmark_load_start,
-			menu);
-		g_signal_handlers_disconnect_by_func(
-			G_OBJECT(menu->bookmark),
-			cb_bookmark_load_stop,
-			menu);
-		g_signal_handlers_disconnect_by_func(
-			G_OBJECT(menu->bookmark),
-			cb_bookmark_load_error,
-			menu);
+		if (KZ_IS_BOOKMARK_FILE(menu->bookmark))
+		{
+			g_signal_handlers_disconnect_by_func(
+				G_OBJECT(menu->bookmark),
+				cb_bookmark_load_start,
+				menu);
+			g_signal_handlers_disconnect_by_func(
+				G_OBJECT(menu->bookmark),
+				cb_bookmark_load_stop,
+				menu);
+			g_signal_handlers_disconnect_by_func(
+				G_OBJECT(menu->bookmark),
+				cb_bookmark_load_error,
+				menu);
+		}
 		g_object_unref(menu->bookmark);
 		menu->bookmark = NULL;
 	}
@@ -382,10 +388,10 @@ kz_bookmark_item_new (KzWindow *kz, KzBookmark *bookmark)
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), NULL);
 	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
 
-	menu = KZ_BOOKMARK_ITEM(g_object_new(KZ_TYPE_BOOKMARK_ITEM,
-					     "kz_window", kz,
-					     "bookmark",  bookmark,
-					     NULL));
+	menu = g_object_new(KZ_TYPE_BOOKMARK_ITEM,
+			   "kz-window", kz,
+			   "bookmark",  bookmark,
+			   NULL);
 
 	return GTK_WIDGET(menu);
 }
@@ -548,7 +554,7 @@ cb_update_button_clicked (GtkWidget *widget, KzBookmarkItem *menu)
 {
 	g_return_if_fail(KZ_IS_BOOKMARK_ITEM(menu));
 
-	kz_bookmark_load_start(menu->bookmark);
+	kz_bookmark_file_load_start(KZ_BOOKMARK_FILE(menu->bookmark));
 }
 
 
@@ -591,7 +597,7 @@ kz_bookmark_item_drag_begin (GtkWidget *widget, GdkDragContext *context)
 	item = KZ_BOOKMARK_ITEM(widget);
 	bookmark = item->bookmark;
 
-	if (kz_bookmark_is_file(bookmark))
+	if (KZ_IS_BOOKMARK_FILE(bookmark))
 		stock_id = KZ_STOCK_REMOTE_BOOKMARK;
 	else if (kz_bookmark_is_folder(bookmark))
 		stock_id = KZ_STOCK_FOLDER;
