@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.h,v 1.28 2004/10/27 07:35:19 ikezoe Exp $
+ *  $Id: kz-bookmark.h,v 1.31 2004/11/25 07:28:47 ikezoe Exp $
  */
 
 #ifndef __KZ_BOOKMARK_H__
@@ -39,7 +39,6 @@ G_BEGIN_DECLS
 
 typedef struct _KzBookmark         KzBookmark;
 typedef struct _KzBookmarkClass    KzBookmarkClass;
-typedef struct _KzBookmarkFileType KzBookmarkFileType;
 
 typedef enum {
 	KZ_BOOKMARK_NORMAL,
@@ -50,20 +49,11 @@ typedef enum {
 } KzBookmarkType;
 
 typedef enum {
-	KZ_BOOKMARK_EDITABLE_FLAG    = 1 << 0,  /* not used yet */
-	KZ_BOOKMARK_FOLDED_FLAG      = 1 << 1,
-	KZ_BOOKMARK_FILE_FLAG        = 1 << 2,
-	KZ_BOOKMARK_SMART_FLAG       = 1 << 3
+	KZ_BOOKMARK_FOLDED_FLAG      = 1 << 0 
 } KzBookmarkFlag;
 
 #define KZ_BOOKMARK_SORT_LAST_MODIFIED "last-modified"
 
-typedef enum {
-	KZ_BOOKMARK_STATE_NORMAL,
-	KZ_BOOKMARK_STATE_LOADING,
-	KZ_BOOKMARK_STATE_SAVING
-} KzBookmarkState;
-
 struct _KzBookmark
 {
 	GObject         parent;
@@ -85,33 +75,11 @@ struct _KzBookmarkClass
 				    KzBookmark  *parent,
 				    KzBookmark  *sibling);
 	void (*children_reordered) (KzBookmark  *boomark);
-
-	void (*load_start)         (KzBookmark  *bookmark);
-	void (*load_completed)     (KzBookmark  *bookmark);
-	void (*save_start)         (KzBookmark  *bookmark);
-	void (*save_completed)     (KzBookmark  *bookmark);
-
-	void (*error)              (KzBookmark  *bookmark,
-				    const gchar *message);
-};
-
-struct _KzBookmarkFileType
-{
-	gint         priority_hint;
-	const gchar *file_type;
-	gboolean   (*is_supported) (KzBookmark  *bookmark,
-				    const gchar *buffer);
-	void       (*init)         (KzBookmark  *bookmark);
-	gboolean   (*from_string)  (KzBookmark  *bookmark,
-				    const gchar *buffer,
-				    guint        length,
-				    GError     **error);
-	gchar     *(*to_string)    (KzBookmark  *bookmark);
 };
 
 
 /* GType */
-GType		kz_bookmark_type_get_type	(void);
+GType		kz_bookmark_type_get_type	(void) G_GNUC_CONST;
 GType		kz_bookmark_get_type		(void);
 
 /* boomark item creating functions */
@@ -121,38 +89,21 @@ KzBookmark     *kz_bookmark_new_with_attrs	(const gchar *title,
 						 const gchar *description);
 KzBookmark     *kz_bookmark_pure_folder_new	(void);
 KzBookmark     *kz_bookmark_separator_new	(void);
-KzBookmark     *kz_bookmark_file_new		(const gchar *location,
-						 const gchar *title,
-						 const gchar *file_type);
-
-KzBookmark     *kz_bookmark_file_create_new	(const gchar *location,
-						 const gchar *title,
-						 const gchar *file_type);
-
 /* set/get properties */
 /*
  * "ID" is md5sum of URI of the parent bookmark file + ":" + ID
  * "title" means user defined title.
  * "document_title" is the original document title.
- * "location" means location of bookmark file itself.
  */
 const gchar    *kz_bookmark_get_id		(KzBookmark  *bookmark);
 const gchar    *kz_bookmark_get_link		(KzBookmark  *bookmark);
 const gchar    *kz_bookmark_get_title		(KzBookmark  *bookmark);
 const gchar    *kz_bookmark_get_document_title	(KzBookmark  *bookmark);
 const gchar    *kz_bookmark_get_description	(KzBookmark  *bookmark);
-const gchar    *kz_bookmark_get_location	(KzBookmark  *bookmark);
-const gchar    *kz_bookmark_get_file_type	(KzBookmark  *bookmark);
 guint		kz_bookmark_get_last_modified	(KzBookmark  *bookmark);
 guint		kz_bookmark_get_last_visited	(KzBookmark  *bookmark);
 guint		kz_bookmark_get_added_time	(KzBookmark  *bookmark);
-guint		kz_bookmark_get_interval	(KzBookmark  *bookmark);
-gboolean        kz_bookmark_is_file             (KzBookmark  *bookmark);
 gboolean        kz_bookmark_is_editable         (KzBookmark  *bookmark);
-gboolean        kz_bookmark_file_is_editable    (KzBookmark  *bookmark_file);
-const gchar    *kz_bookmark_get_xmlrpc          (KzBookmark *bookmark);
-const gchar    *kz_bookmark_get_xmlrpc_user     (KzBookmark *bookmark);
-const gchar    *kz_bookmark_get_xmlrpc_pass     (KzBookmark *bookmark);
 
 void		kz_bookmark_set_id		(KzBookmark  *bookmark,
 						 const gchar *id);
@@ -164,25 +115,12 @@ void		kz_bookmark_set_document_title	(KzBookmark  *bookmark,
 						 const gchar *doc_title);
 void		kz_bookmark_set_description	(KzBookmark  *bookmark,
 						 const gchar *description);
-void		kz_bookmark_set_location	(KzBookmark  *bookmark,
-						 const gchar *location);
-void		kz_bookmark_set_file_type	(KzBookmark  *bookmark,
-						 const gchar *file_type);
 void		kz_bookmark_set_last_modified	(KzBookmark  *bookmark,
 						 guint        time);
 void		kz_bookmark_set_last_visited	(KzBookmark  *bookmark,
 						 guint        time);
 void		kz_bookmark_set_added_time	(KzBookmark  *bookmark,
 						 guint        time);
-void		kz_bookmark_set_interval	(KzBookmark  *bookmark,
-						 guint        interval);
-void		kz_bookmark_set_xmlrpc		(KzBookmark  *bookmark,
-						 const gchar *xmlrpc);
-void		kz_bookmark_set_xmlrpc_user	(KzBookmark  *bookmark,
-						 const gchar *user);
-void		kz_bookmark_set_xmlrpc_pass	(KzBookmark  *bookmark,
-						 const gchar *pass);
-
 /* separator interface */
 gboolean	kz_bookmark_is_separator	(KzBookmark  *bookmark);
 
@@ -222,18 +160,6 @@ void		kz_bookmark_regist_sort_func	(const gchar *type,
 
 KzBookmark *    kz_bookmark_find_bookmark_from_uri (KzBookmark *bookmark,
 						    const gchar *key_uri);
-/* load/save interface */
-/* async */
-gboolean	kz_bookmark_load_start		 (KzBookmark *bookmark);
-void		kz_bookmark_load_stop		 (KzBookmark *bookmark);
-gboolean	kz_bookmark_save_start		 (KzBookmark *bookmark);
-void		kz_bookmark_save_stop		 (KzBookmark *bookmark);
-/* sync */
-void		kz_bookmark_load		 (KzBookmark *bookmark);
-void		kz_bookmark_save		 (KzBookmark *bookmark);
-
-KzBookmarkState kz_bookmark_get_state		 (KzBookmark *bookmark);
-
 G_END_DECLS
 
 #endif /* __KZ_BOOKMARK_H__ */
