@@ -17,13 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.18 2004/10/15 13:05:02 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.c,v 1.22 2004/11/25 02:40:11 ikezoe Exp $
  */
 
 #include "kz-bookmarks-view.h"
 #include <glib/gi18n.h>
 
 #include "gobject-utils.h"
+#include "kz-bookmark-file.h"
 #include "kz-smart-bookmark.h"
 #include "kz-favicon.h"
 
@@ -518,17 +519,17 @@ insert_bookmark(KzBookmarksView *view,
 
 	/* get attrs */
 	title = kz_bookmark_get_title(bookmark);
-	uri = kz_bookmark_is_file(bookmark)
-		? kz_bookmark_get_location(bookmark)
+	uri = KZ_IS_BOOKMARK_FILE(bookmark)
+		? kz_bookmark_file_get_location(KZ_BOOKMARK_FILE(bookmark))
 		: kz_bookmark_get_link(bookmark);
 
-	if (kz_bookmark_is_file(bookmark) ||
+	if (KZ_IS_BOOKMARK_FILE(bookmark) ||
 	    kz_bookmark_is_folder(bookmark))
 	{
 		GtkWidget *image;
 		const gchar *icon;
 
-		icon = kz_bookmark_is_file(bookmark)
+		icon = KZ_IS_BOOKMARK_FILE(bookmark)
 			? KZ_STOCK_REMOTE_BOOKMARK : KZ_STOCK_FOLDER;
 		image = gtk_image_new_from_stock(icon,
 						 GTK_ICON_SIZE_MENU);
@@ -590,7 +591,7 @@ insert_bookmark(KzBookmarksView *view,
 			title_is_editable    = FALSE;
 			location_is_editable = FALSE;
 		}
-		else if (!kz_bookmark_is_file(bookmark) &&
+		else if (!KZ_IS_BOOKMARK_FILE(bookmark) &&
 			 kz_bookmark_is_pure_folder(bookmark))
 		{
 			location_is_editable = FALSE;
@@ -778,8 +779,8 @@ sync_bookmark_properties (KzBookmarksView *view, KzBookmark *bookmark)
 	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 
 	title = kz_bookmark_get_title(bookmark);
-	uri = kz_bookmark_is_file(bookmark)
-		? kz_bookmark_get_location(bookmark)
+	uri = KZ_IS_BOOKMARK_FILE(bookmark)
+		? kz_bookmark_file_get_location(KZ_BOOKMARK_FILE(bookmark))
 		: kz_bookmark_get_link(bookmark);
 
 	treeview = GTK_TREE_VIEW(view);
@@ -949,10 +950,10 @@ cb_bookmark_location_edited (GtkCellRendererText *cell,
 			   TERMINATOR);
 	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 
-	if (kz_bookmark_is_file(bookmark))
+	if (KZ_IS_BOOKMARK_FILE(bookmark))
 	{
-		kz_bookmark_set_location(bookmark, new_text);
-		kz_bookmark_load_start(bookmark);
+		kz_bookmark_file_set_location(KZ_BOOKMARK_FILE(bookmark), new_text);
+		kz_bookmark_file_load_start(KZ_BOOKMARK_FILE(bookmark));
 	}
 	else
 	{
@@ -991,9 +992,9 @@ cb_drag_motion (GtkWidget *widget,
 	if (pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE ||
 	    pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER)
 	{
-		if ((kz_bookmark_is_file(bookmark) &&
-		     !kz_bookmark_file_is_editable(bookmark)) ||
-		    (!kz_bookmark_is_file(bookmark) &&
+		if ((KZ_IS_BOOKMARK_FILE(bookmark) &&
+		     !kz_bookmark_file_is_editable(KZ_BOOKMARK_FILE(bookmark))) ||
+		    (!KZ_IS_BOOKMARK_FILE(bookmark) &&
 		     !kz_bookmark_is_editable(bookmark)))
 		{
 			gdk_drag_status(drag_context, 0, time);
@@ -1064,6 +1065,7 @@ cb_drag_data_received (GtkWidget *widget,
 	GtkTreeViewDropPosition pos;
 	GtkWidget *src_widget;
 	KzBookmark *src, *dest, *parent;
+	KzBookmark *file;
 
 	/* get dest bookmark */
 	gtk_tree_view_get_dest_row_at_pos(GTK_TREE_VIEW(widget),
@@ -1105,6 +1107,17 @@ cb_drag_data_received (GtkWidget *widget,
 		if (!parent) goto ERROR;
 		g_object_ref(src);
 		kz_bookmark_remove(parent, src);
+		
+		if (KZ_IS_BOOKMARK_FILE(parent))
+			file = parent;
+		else
+			file = kz_bookmark_get_parent_file(parent);
+	
+		if (kz_bookmark_file_has_xmlrpc(KZ_BOOKMARK_FILE(file)))
+		{
+			kz_bookmark_file_xmlrpc_remove(KZ_BOOKMARK_FILE(file),
+						       src);
+		}
 
 		if ((pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE ||
 		     pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER) &&
@@ -1138,6 +1151,20 @@ cb_drag_data_received (GtkWidget *widget,
 		if (!parent) goto ERROR;
 
 		kz_bookmark_insert_before(parent, src, dest);
+		
+		if (KZ_IS_BOOKMARK_FILE(parent))
+			file = parent;
+		else
+			file = kz_bookmark_get_parent_file(parent);
+	
+		if (kz_bookmark_file_has_xmlrpc(KZ_BOOKMARK_FILE(file)))
+		{
+			kz_bookmark_file_xmlrpc_insert(KZ_BOOKMARK_FILE(file),
+						       parent,
+						       dest,
+						       src);
+		}
+		g_object_unref(src);
 		gtk_drag_finish(context, TRUE, FALSE, time);
 		break;
 	default:
