@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.56 2004/10/15 13:05:02 ikezoe Exp $
+ *  $Id: kz-xbel.c,v 1.58 2004/10/31 06:38:18 ikezoe Exp $
  */
 
 #include "kazehakase.h"
@@ -29,14 +29,14 @@
 #include <string.h>
 #include <stdlib.h>
 
-static gboolean kz_xbel_is_supported       (KzBookmark  *bookmark,
-					    const gchar *buf);
-static void     kz_xbel_init               (KzBookmark  *bookmark);
-static gboolean kz_xbel_from_string        (KzBookmark  *bookmark,
-					    const gchar *buffer,
-					    guint        length,
-					    GError     **error);
-static gchar   *kz_xbel_to_string          (KzBookmark  *bookmark);
+static gboolean kz_xbel_is_supported       (KzBookmarkFile  *bookmark,
+					    const gchar     *buf);
+static void     kz_xbel_init               (KzBookmarkFile  *bookmark);
+static gboolean kz_xbel_from_string        (KzBookmarkFile  *bookmark,
+					    const gchar     *buffer,
+					    guint            length,
+					    GError         **error);
+static gchar   *kz_xbel_to_string          (KzBookmarkFile   *bookmark);
 
 static void     kz_xbel_notify             (GObject     *object,
 					    GParamSpec  *pspec,
@@ -96,7 +96,7 @@ kz_xbel_get_file_types (gint idx)
 
 
 static gboolean
-kz_xbel_is_supported(KzBookmark *bookmark, const gchar *buf)
+kz_xbel_is_supported(KzBookmarkFile *bookmark, const gchar *buf)
 {
 	const gchar *pos;
 
@@ -119,7 +119,7 @@ kz_xbel_is_supported(KzBookmark *bookmark, const gchar *buf)
 
 
 static void
-kz_xbel_init (KzBookmark *bookmark)
+kz_xbel_init (KzBookmarkFile *bookmark)
 {
 	KzXML *xml;
 
@@ -134,7 +134,6 @@ kz_xbel_init (KzBookmark *bookmark)
 	g_object_set_qdata_full(G_OBJECT(bookmark), xml_quark,
 				xml, (GDestroyNotify) g_object_unref);
 
-	bookmark->flags |= KZ_BOOKMARK_FILE_FLAG;
 	g_object_set(G_OBJECT(bookmark),
 		     "type", KZ_BOOKMARK_PURE_FOLDER,
 		     NULL);
@@ -149,13 +148,13 @@ kz_xbel_init (KzBookmark *bookmark)
 
 
 static gboolean
-kz_xbel_from_string (KzBookmark *bookmark,
+kz_xbel_from_string (KzBookmarkFile *bookmark,
 		     const gchar *buffer, guint length,
 		     GError **error)
 {
 	KzXML *xml;
 
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), FALSE);
+	g_return_val_if_fail(KZ_IS_BOOKMARK_FILE(bookmark), FALSE);
 
 	xml = g_object_get_qdata(G_OBJECT(bookmark), xml_quark);
 	g_return_val_if_fail(KZ_IS_XML(xml), FALSE);
@@ -186,7 +185,7 @@ kz_xbel_from_string (KzBookmark *bookmark,
 			title_node = kz_xml_element_node_new("title");
 			kz_xml_node_append_child(node, title_node);
 
-			bookmark_title = kz_bookmark_get_title(bookmark);
+			bookmark_title = kz_bookmark_get_title(KZ_BOOKMARK(bookmark));
 			if(bookmark_title)
 				title = kz_xml_text_node_new(bookmark_title);
 			else
@@ -199,18 +198,18 @@ kz_xbel_from_string (KzBookmark *bookmark,
 		kz_xml_node_append_child(node, space);
 	}
 
-	kz_xbel_build_tree(bookmark);
+	kz_xbel_build_tree(KZ_BOOKMARK(bookmark));
 
 	return TRUE;
 }
 
 
 static gchar *
-kz_xbel_to_string (KzBookmark *bookmark)
+kz_xbel_to_string (KzBookmarkFile *bookmark)
 {
 	KzXML *xml;
 
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
+	g_return_val_if_fail(KZ_IS_BOOKMARK_FILE(bookmark), NULL);
 
 	xml = g_object_get_qdata(G_OBJECT(bookmark), xml_quark);
 	g_return_val_if_fail(KZ_IS_XML(xml), NULL);
@@ -257,22 +256,6 @@ kz_xbel_notify (GObject *object, GParamSpec *pspec, KzXML *xml)
 		g_free(title);
 	}
 	g_value_unset(&value);
-#if 0
-	else if (!strcmp(prop, "link"))
-	{
-		gchar *uri = g_value_dup_string(&value);
-
-		kz_xml_node_set_attr(node, "href", uri);
-		g_free(uri);
-	}
-	else if (!strcmp(prop, "description"))
-	{
-		gchar *desc = g_value_dup_string(&value);
-
-		xml_node_set_description(node, desc);
-		g_free(desc);
-	}
-#endif
 }
 
 
@@ -340,7 +323,7 @@ parse_metadata_node (KzBookmark *bookmark, KzXMLNode *parent)
 			if (!strncmp(attr->name, "kz:update_interval", 118))
 			{
 				interval = atoi(attr->value);
-				kz_bookmark_set_interval(bookmark, interval);
+				kz_bookmark_file_set_interval(KZ_BOOKMARK_FILE(bookmark), interval);
 			}
 			else if (!strncmp(attr->name, "kz:smart_regex", 14))
 			{
@@ -360,15 +343,15 @@ parse_metadata_node (KzBookmark *bookmark, KzXMLNode *parent)
 			}
 			else if (!strncmp(attr->name, "kz:xmlrpc", 9))
 			{
-				kz_bookmark_set_xmlrpc(bookmark, attr->value);
+				kz_bookmark_file_set_xmlrpc(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
 			else if (!strncmp(attr->name, "kz:xmlrpc_user", 14))
 			{
-				kz_bookmark_set_xmlrpc_user(bookmark, attr->value);
+				kz_bookmark_file_set_xmlrpc_user(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
 			else if (!strncmp(attr->name, "kz:xmlrpc_pass", 14))
 			{
-				kz_bookmark_set_xmlrpc_pass(bookmark, attr->value);
+				kz_bookmark_file_set_xmlrpc_pass(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
 			else if (!strncmp(attr->name, "kz:current_position", 18))
 			{
@@ -554,9 +537,9 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 #warning FIXME! If the file does not exit, we should creat it.
 				const gchar *location = xml_node_get_location(node);
 
-				folder = kz_bookmark_file_new(location,
-							      NULL, NULL);
-				kz_bookmark_load_start(folder);
+				folder = KZ_BOOKMARK(kz_bookmark_file_new(location,
+							      NULL, NULL));
+				kz_bookmark_file_load_start(KZ_BOOKMARK_FILE(folder));
 			}
 			else
 			{
@@ -752,7 +735,7 @@ xml_node_set_location (KzXMLNode *node, KzBookmark *bookmark)
 	const gchar *location;
 	KzXMLNode *metadata_node;
 
-	location = kz_bookmark_get_location(bookmark);
+	location = kz_bookmark_file_get_location(KZ_BOOKMARK_FILE(bookmark));
 	g_return_if_fail(location);
 
 	metadata_node = xml_node_find_metadata_node(node);
@@ -770,7 +753,7 @@ xml_node_set_interval (KzXMLNode *node, KzBookmark *bookmark)
 	gchar *interval;
 	KzXMLNode *metadata_node;
 
-	interval = g_strdup_printf("%d", kz_bookmark_get_interval(bookmark));
+	interval = g_strdup_printf("%d", kz_bookmark_file_get_interval(KZ_BOOKMARK_FILE(bookmark)));
 
 	metadata_node = xml_node_find_metadata_node(node);
 	
@@ -898,10 +881,10 @@ create_xml_node (KzBookmark *bookmark)
 	{
 		node = kz_xml_element_node_new("separator");
 	}
-	else if (kz_bookmark_is_file(bookmark))
+	else if (KZ_IS_BOOKMARK_FILE(bookmark))
 	{
-		const gchar *location = kz_bookmark_get_location(bookmark);
-		guint interval        = kz_bookmark_get_interval(bookmark);
+		const gchar *location = kz_bookmark_file_get_location(KZ_BOOKMARK_FILE(bookmark));
+		guint interval        = kz_bookmark_file_get_interval(KZ_BOOKMARK_FILE(bookmark));
 
 		if (!location || !*location)
 		{
@@ -1036,7 +1019,7 @@ kz_xbel_connect_signals (KzBookmark *bookmark)
 	g_signal_connect(G_OBJECT(bookmark), "notify",
 			 G_CALLBACK(cb_bookmark_notify), NULL);
 
-	if (kz_bookmark_is_file(bookmark)) return;
+	if (KZ_IS_BOOKMARK_FILE(bookmark)) return;
 	if (!kz_bookmark_is_folder(bookmark)) return;
 
 	{
@@ -1070,7 +1053,7 @@ kz_xbel_disconnect_signals (KzBookmark *bookmark)
 		(G_OBJECT(bookmark),
 		 G_CALLBACK(cb_bookmark_notify), NULL);
 
-	if (kz_bookmark_is_file(bookmark)) return;
+	if (KZ_IS_BOOKMARK_FILE(bookmark)) return;
 	if (!kz_bookmark_is_folder(bookmark)) return;
 
 	{
@@ -1201,59 +1184,6 @@ xml_node_set_description (KzXMLNode *parent, const gchar *desc)
 }
 
 
-#if 0
-static void
-xml_node_set_element (KzXMLNode *parent,
-		      const gchar *contents, const gchar *name)
-{
-	KzXMLNode *element_node = NULL, *node, *child;
-
-	g_return_if_fail(parent);
-	g_return_if_fail(name);
-
-	node = kz_xml_node_first_child(parent);
-
-	/* find node */
-	for (; node; node = kz_xml_node_next(node))
-	{
-		if (kz_xml_node_name_is(node, name))
-		{
-			element_node = node;
-			break;
-		}
-	}
-
-	/* remove old element node, or create new element node */
-	if (element_node)
-	{
-		child = kz_xml_node_first_child(node);
-		while(child)
-		{
-			KzXMLNode *next = kz_xml_node_next(child);
-
-			child = kz_xml_node_remove_child(node, child);
-			kz_xml_node_unref(child);
-			child = next;
-		}
-	}
-	else
-	{
-		KzXMLNode *space;
-
-		element_node = kz_xml_element_node_new(name);
-		kz_xml_node_append_child(parent, element_node);
-
-		space = kz_xml_text_node_new("\n");
-		kz_xml_node_append_child(parent, space);
-	}
-
-	/* set new element */
-	child = kz_xml_text_node_new(contents);
-	kz_xml_node_append_child(element_node, child);
-}
-#endif
-
-
 static void
 cb_bookmark_notify (GObject *object, GParamSpec *pspec)
 {
@@ -1466,7 +1396,7 @@ kz_xbel_insert_xml_node (KzBookmark *bookmark,
 	space = kz_xml_text_node_new("\n");
 	kz_xml_node_insert_before(parent_node, space, kz_xml_node_next(node));
 
-	if (kz_bookmark_is_folder(bookmark) && !kz_bookmark_is_file(bookmark))
+	if (kz_bookmark_is_folder(bookmark) && !KZ_IS_BOOKMARK_FILE(bookmark))
 	{
 		GList *node, *children;
 
