@@ -62,38 +62,39 @@ typedef struct
 {
 	KzEmbedEventType type;
 
-	gint     context;
-	gboolean framed_page; /* not used yet */
+	gint             context;
+	gboolean         framed_page; /* not used yet */
 
-	gchar *link;
-	gchar *linktext;
-	gchar *img;
-	gchar *frame_src;
+	gchar           *link;
+	gchar           *linktext;
+	gchar           *img;
+	gchar           *frame_src;
 	
-	gpointer element; /* indicates pointer of dom element */
+	gpointer         element; /* indicates pointer of dom element */
 } KzEmbedEvent;
 
 typedef struct
 {
 	KzEmbedEvent cinfo;
-	gint key;
-	gint modifier;
-	gint char_code;
+	gint         key;
+	gint         modifier;
+	gint         char_code;
 } KzEmbedEventKey;
 
 typedef struct
 {
 	KzEmbedEvent cinfo;
-	gint button;
-	gint modifier;
-	gint x, y;
+	gint         button;
+	gint         modifier;
+	gint         x, y;
 
 	guint timestamp; /* not used yet */
 } KzEmbedEventMouse;
 
 
 KzEmbedEvent *kz_embed_event_new  (KzEmbedEventType type);
-void          kz_embed_event_free (KzEmbedEvent    *cinfo);
+KzEmbedEvent *kz_embed_event_copy (KzEmbedEvent    *event);
+void          kz_embed_event_free (KzEmbedEvent    *event);
 
 G_END_DECLS
 
