@@ -22,9 +22,9 @@
 
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
 #include "gobject-utils.h"
-#include "intl.h"
 #include "kazehakase.h"
 #include "kz-icons.h"
 
@@ -36,7 +36,6 @@
 #include "prefs_ui/prefs_key_accel.h"
 #include "prefs_ui/prefs_gesture.h"
 #include "prefs_ui/prefs_proxy.h"
-#include "prefs_ui/prefs_session.h"
 #include "prefs_ui/prefs_ui_editor.h"
 #include "prefs_ui/prefs_privacy.h"
 #include "prefs_ui/prefs_external_program.h"
@@ -139,7 +138,6 @@ kz_prefs_win_class_init (KzPrefsWinClass *klass)
 	ADD_PAGE_ENTRY(prefs_key_accel_get_entry);
 	ADD_PAGE_ENTRY(prefs_gesture_get_entry);
 	ADD_PAGE_ENTRY(prefs_proxy_get_entry);
-	ADD_PAGE_ENTRY(prefs_session_get_entry);
 	ADD_PAGE_ENTRY(prefs_privacy_get_entry); 
 	/* ADD_PAGE_ENTRY(prefs_ui_editor_get_entry); */ 
 	ADD_PAGE_ENTRY(prefs_external_program_get_entry);
