@@ -22,21 +22,21 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
 #include "kazehakase.h"
 #include "kz-actions.h"
 #include "kz-actions-tab.h"
 #include "kz-icons.h"
 #include "kz-favicon.h"
 #include "kz-input-event-box.h"
-
+#include "kz-bookmark-file.h"
 
 enum {
 	PROP_0,
 	PROP_KZ_WINDOW,
-	PROP_KZ_MOZ_EMBED
+	PROP_KZ_EMBED
 };
 
 
@@ -111,21 +111,18 @@ static void     cb_profile_changed              (KzProfile *profile,
 						 const gchar *key,
 						 const gchar *old_value,
 						 KzTabLabel *kztab);
-
+#if 0
 static void     cb_favicon_changed              (KzFavicon *kzfav,
 						 gchar *uri,
 						 KzTabLabel *kztab);
-static void     cb_close_button_state_changed   (GtkWidget *widget,
-						 GtkStateType previous_state);
+#endif
 
-/* callbacks for mozilla */
-static void cb_title_changed (GtkMozEmbed *embed, KzTabLabel *kztab);
-static void cb_net_start     (GtkMozEmbed *embed, KzTabLabel *kztab);
-static void cb_net_stop      (GtkMozEmbed *embed, KzTabLabel *kztab);
+/* callbacks for embed */
+static void cb_title_changed (KzEmbed *embed, KzTabLabel *kztab);
+static void cb_net_start     (KzEmbed *embed, KzTabLabel *kztab);
+static void cb_net_stop      (KzEmbed *embed, KzTabLabel *kztab);
+static void cb_progress      (KzEmbed *embed, KzTabLabel *kztab);
 static void cb_destroy       (GtkObject *object,  KzTabLabel *kztab);
-static void cb_net_state_all (GtkMozEmbed *embed, const char *aURI,
-			      gint state, gint status,
-			      KzTabLabel *kztab);
 
 static void make_progress_circle (GtkWidget *widget);
 
@@ -199,11 +196,11 @@ kz_tab_label_class_init (KzTabLabelClass *klass)
 
 	g_object_class_install_property
 		(gobject_class,
-		 PROP_KZ_MOZ_EMBED,
-		 g_param_spec_object ("kz-moz-embed",
-				      _("KzMozEmbed"),
-				      _("The KzMozEmbed object to observe"),
-				      KZ_TYPE_MOZ_EMBED,
+		 PROP_KZ_EMBED,
+		 g_param_spec_object ("kz-embed",
+				      _("KzEmbed"),
+				      _("The KzEmbed object to observe"),
+				      KZ_TYPE_EMBED,
 				      G_PARAM_READWRITE |
 				      G_PARAM_CONSTRUCT_ONLY));
 }
@@ -239,6 +236,9 @@ kz_tab_label_init (KzTabLabel *kztab)
 	kztab->circle           = NULL;
 	kztab->mask             = NULL;
 
+	kztab->history    = kz_bookmark_pure_folder_new();
+	kz_bookmark_set_title(kztab->history, _("Tab"));
+
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(kztab->eventbox), hbox);
 	gtk_widget_show(hbox);
@@ -262,14 +262,7 @@ kz_tab_label_init (KzTabLabel *kztab)
 	gtk_button_set_relief(GTK_BUTTON(kztab->close_button), GTK_RELIEF_NONE);
 	g_signal_connect(G_OBJECT(kztab->close_button), "clicked", 
 			 G_CALLBACK(cb_close_button_clicked), kztab);
-	/* Picked from galeon-1.3.11a */
-	/* work around a cosmetic bug in gtk where buttons with GTK_RELIEF_NONE
-	 * have annoyingly visible border only when in GTK_STATE_ACTIVE (ie. in
-	 * inactive tabs) */
-	g_signal_connect(G_OBJECT (kztab->close_button), "state_changed",
-			 G_CALLBACK (cb_close_button_state_changed),
-			 NULL);
-		
+
 	close_image = gtk_image_new_from_stock(GTK_STOCK_CLOSE,
 					       GTK_ICON_SIZE_MENU);
 	gtk_widget_size_request(close_image, &size);
@@ -335,22 +328,19 @@ kz_tab_label_constructor (GType                  type,
 	kztab = KZ_TAB_LABEL(object);
 
 	/* set signals */
-	g_signal_connect(G_OBJECT(kztab->kzembed), "title",
+	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-title",
 			 G_CALLBACK(cb_title_changed), kztab);
-	g_signal_connect(G_OBJECT(kztab->kzembed), "net-start",
+	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-net-start",
 			 G_CALLBACK(cb_net_start), kztab);
-	g_signal_connect(G_OBJECT(kztab->kzembed), "net-stop",
+	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-net-stop",
 			 G_CALLBACK(cb_net_stop), kztab);
+	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-progress",
+			 G_CALLBACK(cb_progress), kztab);
 	g_signal_connect(G_OBJECT(kztab->kzembed), "destroy",
 			 G_CALLBACK(cb_destroy), kztab);
-	g_signal_connect(G_OBJECT(kztab->kzembed), "net-state-all",
-			 G_CALLBACK(cb_net_state_all), kztab);
-
-	/* connect favicon signal */
-	kz_favicon_connect_signal(kztab->kz->kzfav, kztab->kzembed);
 
 	/* set label text */
-	title = kz_moz_embed_ensure_title(kztab->kzembed);
+	title = kz_embed_ensure_title(kztab->kzembed);
 	kz_tab_label_set_text(kztab, title);
 	g_free(title);
 
@@ -380,12 +370,9 @@ kz_tab_label_dispose (GObject *object)
 		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
 						     cb_title_changed, kztab);
 		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
-						     cb_destroy, kztab);
+						     cb_progress, kztab);
 		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
-						     cb_net_state_all, kztab);
-		/* disconnect favicon signal */
-		kz_favicon_disconnect_signal(kztab->kz->kzfav, kztab->kzembed);
-
+						     cb_destroy, kztab);
 		g_object_unref(kztab->kzembed);
 		kztab->kzembed = NULL;
 	}
@@ -399,6 +386,21 @@ kz_tab_label_dispose (GObject *object)
 		kztab->priv->favicon_signal = 0;
 	}
 
+	if (kztab->history)
+	{
+		gboolean save_session = FALSE;
+		
+		kz_window_append_closed_tab(kztab->kz, kztab->history);
+	
+		kz_bookmark_remove(kztab->kz->tabs, kztab->history);
+		g_object_unref(kztab->history);
+		kztab->history = NULL;
+		
+		KZ_CONF_GET("Session", "save", save_session, BOOL);
+		if (save_session && !kztab->kz->is_closing_all)
+			kz_bookmark_file_save(KZ_BOOKMARK_FILE(kz_bookmarks->current_session));
+	}
+
 	if (kztab->kz)
 	{
 		g_object_unref(kztab->kz);
@@ -445,7 +447,7 @@ kz_tab_label_set_property (GObject         *object,
 	case PROP_KZ_WINDOW:
 		tablabel->kz = g_object_ref(g_value_get_object(value));
 		break;
-	case PROP_KZ_MOZ_EMBED:
+	case PROP_KZ_EMBED:
 		tablabel->kzembed = g_object_ref(g_value_get_object(value));
 		break;
 	default:
@@ -468,7 +470,7 @@ kz_tab_label_get_property (GObject         *object,
 	case PROP_KZ_WINDOW:
 		g_value_set_object(value, tablabel->kz);
 		break;
-	case PROP_KZ_MOZ_EMBED:
+	case PROP_KZ_EMBED:
 		g_value_set_object(value, tablabel->kzembed);
 		break;
 	default:
@@ -479,17 +481,17 @@ kz_tab_label_get_property (GObject         *object,
 
 
 GtkWidget *
-kz_tab_label_new (KzWindow *kz, KzMozEmbed *kzembed)
+kz_tab_label_new (KzWindow *kz, KzEmbed *kzembed)
 {
 	KzTabLabel *kztab;
 
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), NULL);
-	g_return_val_if_fail(KZ_IS_MOZ_EMBED(kzembed), NULL);
+	g_return_val_if_fail(KZ_IS_EMBED(kzembed), NULL);
 
-	kztab = KZ_TAB_LABEL(g_object_new(KZ_TYPE_TAB_LABEL,
-					  "kz-window",    kz,
-					  "kz-moz-embed", kzembed,
-					  NULL));
+	kztab = g_object_new(KZ_TYPE_TAB_LABEL,
+			     "kz-window", kz,
+			     "kz-embed",  kzembed,
+			     NULL);
 
 	return GTK_WIDGET(kztab);
 }
@@ -507,6 +509,7 @@ kz_tab_label_set_text(KzTabLabel *kztab, const gchar *text)
 	markup = g_strdup_printf("<span foreground=\"%s\">%s</span>",
 				 label_color[kztab->state],
 				 escaped);
+
 	gtk_label_set_markup(GTK_LABEL(kztab->label), markup);
 	gtk_tooltips_set_tip(kztab->tooltips, GTK_WIDGET(kztab->eventbox),
 			     text, NULL);
@@ -524,22 +527,13 @@ kz_tab_label_set_state (KzTabLabel *kztab,
 
 	if (!GTK_WIDGET_REALIZED(kztab)) return;
 
-	switch(state)
+	kztab->state = state;
+	if (state == KZ_TAB_LABEL_STATE_NORMAL)
 	{
-	case KZ_TAB_LABEL_STATE_LOADING:
-		kztab->state = state;
-		break;
-	case KZ_TAB_LABEL_STATE_LOADED:
-		kztab->state = state;
-		break;
-	case KZ_TAB_LABEL_STATE_NORMAL:
 		kz_tab_label_set_visited(kztab);
-	default:
-		kztab->state = KZ_TAB_LABEL_STATE_NORMAL;
-		break;
 	}
 	
-	title = kz_moz_embed_ensure_title(kztab->kzembed);
+	title = kz_embed_ensure_title(kztab->kzembed);
 	kz_tab_label_set_text(kztab, title);
 	g_free(title);
 }
@@ -615,7 +609,7 @@ kz_tab_label_realize (GtkWidget *widget)
 
 	make_progress_circle(widget);
 
-	if (kz_moz_embed_is_loading(kztab->kzembed))
+	if (kz_embed_is_loading(kztab->kzembed))
 		kz_tab_label_set_state (kztab, KZ_TAB_LABEL_STATE_LOADING);
 }
 #if 0
@@ -733,17 +727,17 @@ kz_tab_label_drag_motion (GtkWidget *widget,
 			  guint time)
 {
 	KzTabLabel *kztab;
-	KzMozEmbed *current_kzembed;
+	KzEmbed *current_kzembed;
 	gint page_num;
 
 	g_return_val_if_fail(KZ_TAB_LABEL(widget), FALSE);
 	kztab = KZ_TAB_LABEL(widget);
 
-	g_return_val_if_fail (KZ_IS_MOZ_EMBED(kztab->kzembed), FALSE);
+	g_return_val_if_fail (KZ_IS_EMBED(kztab->kzembed), FALSE);
 
-	current_kzembed = KZ_MOZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kztab->kz));
+	current_kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kztab->kz));
 
-	if (KZ_MOZ_EMBED(kztab->kzembed) == current_kzembed)
+	if (KZ_EMBED(kztab->kzembed) == current_kzembed)
 		return FALSE;
 
 	page_num = gtk_notebook_page_num(GTK_NOTEBOOK(kztab->kz->notebook),
@@ -766,10 +760,10 @@ kz_tab_label_drag_data_get (GtkWidget        *widget,
 	g_return_if_fail(KZ_IS_TAB_LABEL(widget));
 	kztab = KZ_TAB_LABEL(widget);
 
-	g_return_if_fail (KZ_IS_MOZ_EMBED(kztab->kzembed));
+	g_return_if_fail (KZ_IS_EMBED(kztab->kzembed));
 
-	uri   = kz_moz_embed_get_location(kztab->kzembed);
-	title = kz_moz_embed_get_title(kztab->kzembed);
+	uri   = kz_embed_get_location(kztab->kzembed);
+	title = kz_embed_get_title(kztab->kzembed);
 
 	if (!uri || !*uri) return;
 
@@ -842,7 +836,7 @@ kz_tab_label_drag_data_received (GtkWidget *widget,
 	g_return_if_fail(KZ_IS_TAB_LABEL(widget));
 	kztab = KZ_TAB_LABEL(widget);
 
-	g_return_if_fail (KZ_IS_MOZ_EMBED(kztab->kzembed));
+	g_return_if_fail (KZ_IS_EMBED(kztab->kzembed));
 
 	switch (info)
 	{
@@ -868,7 +862,7 @@ kz_tab_label_drag_data_received (GtkWidget *widget,
 		if (data->length < 0) return;
 
 		strings = g_strsplit(data->data, "\n", 2);
-		kz_moz_embed_load_url(kztab->kzembed,
+		kz_embed_load_url(kztab->kzembed,
 				      strings[0]);
 		g_strfreev(strings);
 		break;
@@ -940,7 +934,6 @@ static void
 kz_tab_label_move_page(KzTabLabel *kztab, KzTabLabel *dest_kztab)
 {
 	GtkWidget *src_page;
-
 	GtkNotebook *notebook;
 	gint dest_pos;
 
@@ -951,19 +944,16 @@ kz_tab_label_move_page(KzTabLabel *kztab, KzTabLabel *dest_kztab)
 	dest_pos = gtk_notebook_page_num(notebook,
 					 GTK_WIDGET(dest_kztab->kzembed));
 
+	src_page = GTK_WIDGET(kztab->kzembed);
 	if (dest_kztab->kz != kztab->kz)
-	{
-		src_page = GTK_WIDGET(kztab->kzembed);
-		kz_window_move_tab(dest_kztab->kz, GTK_WIDGET(src_page));
-	}
-	else
-	{
-		src_page = GTK_WIDGET(kztab->kzembed);
-	}
-
+		kz_window_move_tab(dest_kztab->kz, src_page);
+	
 	kz_window_reorder_tab(dest_kztab->kz, src_page, dest_pos);
 	kz_actions_set_sensitive
-		(kztab->kz, KZ_MOZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kztab->kz)));
+		(kztab->kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kztab->kz)));
+
+	if (dest_kztab->kz != kztab->kz)
+		gtk_widget_destroy(GTK_WIDGET(kztab));
 }
 
 
@@ -1034,26 +1024,26 @@ cb_profile_changed (KzProfile *profile,
 	kz_tab_label_sync_to_profile (kztab);
 }
 
-/* callbacks for mozilla */
+/* callbacks for embed */
 
 static void
-cb_title_changed (GtkMozEmbed *embed, KzTabLabel *kztab)
+cb_title_changed (KzEmbed *embed, KzTabLabel *kztab)
 {
 	gchar *title;
 
-	g_return_if_fail(KZ_IS_MOZ_EMBED(embed));
+	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
-	title = kz_moz_embed_ensure_title(kztab->kzembed);
+	title = kz_embed_ensure_title(kztab->kzembed);
 	kz_tab_label_set_text(kztab, title);
 	g_free(title);
-	
+#if 0
 	if (!kztab->priv->favicon_signal)
 	{
 		gchar *detailed_signal;
 		const gchar *location;
 
-		location = kz_moz_embed_get_location(kztab->kzembed);
+		location = kz_embed_get_location(kztab->kzembed);
 		if (!location)
 			return;
 
@@ -1064,15 +1054,18 @@ cb_title_changed (GtkMozEmbed *embed, KzTabLabel *kztab)
 							       kztab);
 		g_free(detailed_signal);
 	}
+#endif
 }
 
 static void
-cb_net_start (GtkMozEmbed *embed, KzTabLabel *kztab)
+cb_net_start (KzEmbed *embed, KzTabLabel *kztab)
 {
+	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	kz_tab_label_set_state(kztab, KZ_TAB_LABEL_STATE_LOADING);
 
+#if 0
 	/* if connected signal exists, disconnect it. */
 	if (kztab->priv->favicon_signal)
 	{
@@ -1080,7 +1073,7 @@ cb_net_start (GtkMozEmbed *embed, KzTabLabel *kztab)
 					    kztab->priv->favicon_signal);
 		kztab->priv->favicon_signal = 0;
 	}
-
+#endif
 	if (kztab->favicon_pixbuf)
 	{
 		gtk_image_set_from_pixbuf(GTK_IMAGE(kztab->favicon), NULL);
@@ -1092,13 +1085,23 @@ cb_net_start (GtkMozEmbed *embed, KzTabLabel *kztab)
 }
 
 static void
-cb_net_stop (GtkMozEmbed *embed, KzTabLabel *kztab)
+cb_net_stop (KzEmbed *embed, KzTabLabel *kztab)
 {
 	GtkNotebook *note;
 	gboolean show_favicon;
+	gboolean save_session = FALSE;
 
+	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
+	kz_embed_get_history(KZ_EMBED(embed), 
+			     kztab->history);
+
+	/* save session */
+	KZ_CONF_GET("Session", "save", save_session, BOOL);
+	if (save_session && !kztab->kz->is_closing_all)
+		kz_bookmark_file_save(KZ_BOOKMARK_FILE(kz_bookmarks->current_session));
+
 	note = GTK_NOTEBOOK(kztab->kz->notebook);
 	if(gtk_notebook_page_num(note, GTK_WIDGET(embed)) ==
 	   gtk_notebook_get_current_page(note))
@@ -1107,20 +1110,37 @@ cb_net_stop (GtkMozEmbed *embed, KzTabLabel *kztab)
 	}
 	else
 	{
-		kz_tab_label_set_state(kztab, KZ_TAB_LABEL_STATE_LOADED);
-	}
+		KzBookmark *bookmark = NULL;
+		guint cur, last_modified, last_visited = 0;
+		GList *children;
+	
+		cur = kz_bookmark_get_current(kztab->history);
+		children = kz_bookmark_get_children(kztab->history);
+		bookmark = KZ_BOOKMARK(g_list_nth_data(children, cur));
+		g_list_free(children);
 
-	if (kztab->favicon_pixbuf)
-	{
-		gtk_image_set_from_pixbuf(GTK_IMAGE(kztab->favicon),
-					  kztab->favicon_pixbuf);
-		gtk_widget_show(kztab->favicon);
+		if (bookmark)
+			last_visited = kz_bookmark_get_last_visited(bookmark);
+		last_modified = kz_embed_get_last_modified(embed);
+
+		if (last_modified != 0 && last_visited > last_modified)
+			kz_tab_label_set_state(kztab, KZ_TAB_LABEL_STATE_NORMAL);
+		else
+			kz_tab_label_set_state(kztab, KZ_TAB_LABEL_STATE_LOADED);
 	}
-	else
-		gtk_image_set_from_pixbuf(GTK_IMAGE(kztab->favicon),
-					  NULL);
 
 	KZ_CONF_GET("Tab", "show_favicon", show_favicon, BOOL);
+
+	if (show_favicon)
+	{
+		const gchar *uri;
+		uri = kz_embed_get_location(KZ_EMBED(kztab->kzembed));
+		kztab->favicon_pixbuf = kz_favicon_get_pixbuf(kztab->kz->kzfav, uri,
+							      GTK_ICON_SIZE_MENU);
+		gtk_image_set_from_pixbuf(GTK_IMAGE(kztab->favicon),
+					  kztab->favicon_pixbuf);
+	}
+
 	kz_tab_label_set_show_favicon(kztab, show_favicon);
 }
 
@@ -1130,23 +1150,23 @@ static void
 cb_destroy (GtkObject *object, KzTabLabel *kztab)
 {
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+	g_object_unref(kztab->kzembed);
 	kztab->kzembed = NULL;
 }
 
 
 static void
-cb_net_state_all (GtkMozEmbed *embed, const char *aURI,
-		  gint state, gint status,
-		  KzTabLabel *kztab)
+cb_progress (KzEmbed *embed, KzTabLabel *kztab)
 {
 	gdouble progress;
 	GtkWidget *widget;	       
 	GdkGC *gc;
 
+	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	widget = GTK_WIDGET(kztab);
-	progress = kz_moz_embed_get_progress(KZ_MOZ_EMBED(embed));
+	progress = kz_embed_get_progress(KZ_EMBED(embed));
 
 	if(GTK_WIDGET_REALIZED(widget))
 	{
@@ -1190,7 +1210,7 @@ cb_net_state_all (GtkMozEmbed *embed, const char *aURI,
 	}
 }
 
-
+#if 0
 static void
 cb_favicon_changed (KzFavicon *kzfav, gchar *uri, KzTabLabel *kztab)
 {
@@ -1219,21 +1239,8 @@ cb_favicon_changed (KzFavicon *kzfav, gchar *uri, KzTabLabel *kztab)
 		gtk_image_set_from_pixbuf(GTK_IMAGE(kztab->favicon),
 					  kztab->favicon_pixbuf);
 	}
-
-	KZ_CONF_GET("Tab", "show_favicon", show_favicon, BOOL);
-	kz_tab_label_set_show_favicon(kztab, show_favicon);
-}
-
-
-static void
-cb_close_button_state_changed (GtkWidget *widget,
-			       GtkStateType previous_state)
-{
-	if (GTK_WIDGET_STATE(widget) == GTK_STATE_ACTIVE)
-	{
-		gtk_widget_set_state (widget, GTK_STATE_NORMAL);
-	}
 }
+#endif
 
 
 gboolean
@@ -1247,28 +1254,81 @@ kz_tab_label_get_lock (KzTabLabel *kztab)
 void
 kz_tab_label_set_lock (KzTabLabel *kztab, gboolean lock)
 {
+	gboolean save = FALSE;
+
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 	kztab->priv->lock = lock;
-	kz_moz_embed_set_lock(kztab->kzembed, lock);
+	kz_embed_set_lock(kztab->kzembed, lock);
+	kz_actions_set_sensitive(kztab->kz, kztab->kzembed);
+	
+	kz_bookmark_set_lock(kztab->history, lock);
+	KZ_CONF_GET("Session", "save", save, BOOL);
+	if (save)
+		kz_bookmark_file_save(KZ_BOOKMARK_FILE(kz_bookmarks->current_session));
 	kz_tab_label_sync_to_profile(kztab);
 }
 
+void
+kz_tab_label_set_history (KzTabLabel *kztab, KzBookmark *history)
+{	
+	GList *children, *node;
+
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+	
+	kz_bookmark_remove_all(kztab->history);
+
+	children = kz_bookmark_get_children(history);
+	for (node =children; node; node = g_list_next(node))
+	{
+		KzBookmark *new;
+		KzBookmark *child = KZ_BOOKMARK(node->data);
+
+		new = kz_bookmark_new_with_attrs(kz_bookmark_get_title(child),
+						 kz_bookmark_get_link(child),
+						 NULL);
+		kz_bookmark_set_last_visited(new, 
+					     kz_bookmark_get_last_visited(child));
+		kz_bookmark_append(kztab->history, new);
+		g_object_unref(new);
+	}
+	kz_bookmark_set_current(kztab->history,
+				kz_bookmark_get_current(history));
+	
+	g_list_free(children);
+
+	kz_embed_set_history(kztab->kzembed, 
+			     kztab->history);
+}
 static void
 kz_tab_label_set_visited (KzTabLabel *kztab)
 {
 	KzBookmark *bookmark = NULL;
 	const gchar *uri;
+	GTimeVal now;
+	guint cur;
+	GList *children;
 	
-	uri = kz_moz_embed_get_location(kztab->kzembed);
-	/* find the bookmark which has the same uri */
+	g_get_current_time(&now);
+
+	cur = kz_bookmark_get_current(kztab->history);
+	children = kz_bookmark_get_children(kztab->history);
+	bookmark = KZ_BOOKMARK(g_list_nth_data(children, cur));
+	g_list_free(children);
+
+	if (bookmark)
+	{
+		gboolean save_session = FALSE;
+		kz_bookmark_set_last_visited(bookmark, now.tv_sec);
+		/* save session */
+		KZ_CONF_GET("Session", "save", save_session, BOOL);
+		if (save_session && !kztab->kz->is_closing_all)
+			kz_bookmark_file_save(KZ_BOOKMARK_FILE(kz_bookmarks->current_session));
+	}
+	/* find the bookmark which has the same uri from the system bookmark */
+	uri = kz_embed_get_location(kztab->kzembed);
 	bookmark = kz_bookmark_find_bookmark_from_uri(kz_bookmarks->menu,
 						      uri);
 	if (bookmark)
-	{
-		GTimeVal now;
-
-		g_get_current_time(&now);
 		kz_bookmark_set_last_visited(bookmark, now.tv_sec);
-	}
 }
 
