@@ -21,6 +21,7 @@
 #include "kz-mozprogresslistener.h"
 #include "gobject-utils.h"
 #include "kz-downloader-group.h"
+#include "kz-mozdownloader.h"
 
 #include <nsIFileURL.h>
 #include <nsILocalFile.h>
@@ -153,10 +154,14 @@ KzMozProgressListener::Init(nsIURI *aSource,
 	aTarget->GetLeafName(leafName);
 #endif
 	KzDownloaderGroup *dlgrp = kz_downloader_group_get_instance();
+#if 0
 	mDownloader = kz_downloader_group_add_moz_downloader(dlgrp,
 							     this,
 							     NS_ConvertUCS2toUTF8(leafName).get());
-	g_object_ref(mDownloader);
+#else
+	mDownloader = kz_moz_downloader_new(this, NS_ConvertUCS2toUTF8(leafName).get());
+	kz_downloader_group_add_downloader(dlgrp, KZ_DOWNLOADER(mDownloader));
+#endif
 	g_object_unref(dlgrp);
 	return NS_OK;
 }
