@@ -106,19 +106,26 @@ public:
 	
 	nsresult GetSHistory       (nsISHistory **aSHistory);
 
-	nsresult GetAttributeFromNode (nsIDOMNode *node, 
-				       char *name,
-				       char **value);
+	nsresult GetAttributeFromNode    (nsIDOMNode *node, 
+				          const nsAString &attr,
+				          char **value);
 	nsresult GetLinkAndTitleFromNode (nsIDOMDocument *domDoc, 
 					  nsIDOMNode *node,
 			                  gchar **url, gchar **title);
-	nsresult GetLinkFromNode  (nsIDOMDocument *domDoc,
-				   nsIDOMNode *node,
-		                   gchar **url);
-	nsresult GetLinksFromWindow   (nsIDOMWindow *domWindow,
-				       GList **list,
-				       nsISelection *selection, 
-				       gboolean selected_only);
+	nsresult GetLinkFromNode         (nsIDOMDocument *domDoc,
+				          nsIDOMNode *node,
+		                          gchar **url);
+	nsresult GetLinksFromWindow      (nsIDOMWindow *domWindow,
+				          GList **list,
+				          nsISelection *selection, 
+				          gboolean selected_only);
+	nsresult GetPostData             (nsIHistoryEntry *he,
+				          nsAString &postData);
+	nsresult SetPostData             (nsIHistoryEntry *he,
+				          const nsAString &postData);
+	nsresult FineScroll              (int horiz, int vert);
+	nsresult PageUp			 (void);
+	nsresult PageDown		 (void);
 
 	nsCOMPtr<nsIWebBrowser>    mWebBrowser;
 protected:
@@ -155,7 +162,7 @@ protected:
 	void 	  SetAttributes     (nsIDOMNode *node, 
 			             nsIDOMDocument *domDoc,
 			             nsAString &aString);
-	void      SetStartTag       (const gchar *tagname,
+	void      SetStartTag       (const nsAString &tag,
 			   	     nsIDOMDocument *domDoc,
 			             nsAString &aString);
 	void     GetFileToLocal     (const nsACString &URI,
