@@ -21,9 +21,10 @@
 #include "prefs_font.h"
 
 #include <string.h>
+#include <glib/gi18n.h>
 #include "mozilla-prefs.h"
-#include "utils/intl.h"
 #include "kazehakase.h"
+#include "gtk-utils.h"
 
 
 #define DATA_KEY "KzPrefsFont::info"
@@ -61,12 +62,12 @@ typedef struct _KzPrefsFont
 {
 	GtkWidget     *main_vbox;
 
-	GtkOptionMenu *lang_option_menu;
-	GtkOptionMenu *propotional_menu;
+	GtkComboBox   *lang_option_menu;
+	GtkComboBox   *propotional_menu;
 
-	GtkCombo      *serif_combo;
-	GtkCombo      *sans_serif_combo;
-	GtkCombo      *monospace_combo;
+	GtkComboBox  *serif_combo;
+	GtkComboBox  *sans_serif_combo;
+	GtkComboBox  *monospace_combo;
 
 	GtkSpinButton *variable_size_spin;
 	GtkSpinButton *fixed_size_spin;
@@ -134,43 +135,6 @@ static const FontsLanguageInfo fonts_language[] =
 static const guint n_fonts_languages = G_N_ELEMENTS (fonts_language);
 
 
-#define CREATE_MENU(menu, array, n_array, field)                               \
-{                                                                              \
-	gint i;                                                                \
-                                                                               \
-	menu = gtk_menu_new ();                                                \
-                                                                               \
-	for (i = 0; i < n_array; i++)                                          \
-	{                                                                      \
-		GtkWidget *item;                                               \
-                                                                               \
-		item = gtk_menu_item_new_with_label (_(array[i].field));       \
-		gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);            \
-		gtk_widget_show (item);                                        \
-	}                                                                      \
-}
-
-
-#define SET_DEFAULT_HISTORY(menu, key, array, n_array, field)                  \
-{                                                                              \
-	gchar *str;                                                            \
-	gint i;                                                                \
-                                                                               \
-	if (mozilla_prefs_get_string(key, &str))                               \
-	{                                                                      \
-		for (i = 0; i < n_array; i++)                                  \
-		{                                                              \
-			if (!strcmp(str, array[i].field))                      \
-			{                                                      \
-				gtk_option_menu_set_history(GTK_OPTION_MENU(menu), i); \
-				break;                                         \
-			}                                                      \
-		}                                                              \
-		g_free(str);                                                   \
-	}                                                                      \
-}
-
-
 static FontPref *
 font_pref_new (const gchar *lang)
 {
@@ -226,23 +190,36 @@ compare_font_pref (gconstpointer a, gconstpointer b)
 
 
 static void
-font_combo_set (GtkCombo *combo,
+font_combo_set (GtkComboBox *combo,
 		const gchar *lang, const gchar *type,
 		const gchar *font)
 {
-	GList *fonts;
+	GList *fonts, *node;
 	const gchar *use_font = NULL;
 	gchar *default_font = NULL;
+	GtkListStore *store;
+	gint select = 0, i = 0;
 
+	/* remove old list */
+	store = GTK_LIST_STORE(gtk_combo_box_get_model(combo));
+	gtk_list_store_clear(store);
+	
 	mozilla_prefs_get_font_list(lang, type, &fonts, &default_font);
 
-	if (!fonts) fonts = g_list_alloc();
-	gtk_combo_set_popdown_strings (combo, fonts);
+	if (!fonts) return;
 
 	use_font = font && *font ? font : default_font;
-	if (use_font)
-		gtk_entry_set_text(GTK_ENTRY(combo->entry), use_font);
 
+	for (node = g_list_first(fonts); node; node = g_list_next(node))
+	{
+		if (use_font && node->data && !strcmp(use_font, node->data))
+			select = i;
+		gtk_combo_box_append_text(combo, node->data);	
+		i++;
+	}
+
+	gtk_combo_box_set_active(combo, select);
+	
 	g_free (default_font);
 
 	g_list_foreach (fonts, (GFunc)g_free, NULL);
@@ -278,11 +255,11 @@ font_spin_set (GtkSpinButton *spin,
 static const gchar *
 get_current_lang(KzPrefsFont *prefsui)
 {
-	gint i;
+	guint i;
 
 	g_return_val_if_fail(prefsui, NULL);
 
-	i = gtk_option_menu_get_history(prefsui->lang_option_menu);
+	i = gtk_combo_box_get_active(prefsui->lang_option_menu);
 	if (i >= 0 && i < n_fonts_languages)
 		return fonts_language[i].code;
 
@@ -331,7 +308,9 @@ font_prefs_reset (KzPrefsFont *prefsui)
 			      "size.fixed", lang, pref->fixed_size);
 		font_spin_set(prefsui->min_size_spin,
 			      "min-size.variable", lang, pref->min_size);
-	} else {
+	}
+	else
+	{
 		g_warning("KzPrefsFont: "
 			  "Unexpected language ID was selected!");
 	}
@@ -352,22 +331,22 @@ prefs_font_destroy (gpointer data)
 
 
 static void
-cb_font_lang_changed (GtkOptionMenu *option_menu, KzPrefsFont *prefsui)
+cb_font_lang_changed (GtkComboBox *option_menu, KzPrefsFont *prefsui)
 {
-	g_return_if_fail(GTK_IS_OPTION_MENU(option_menu));
+	g_return_if_fail(GTK_IS_COMBO_BOX(option_menu));
 	font_prefs_reset(prefsui);
 }
 
 
 static void
-store_new_font (GtkEntry *entry, KzPrefsFont *prefsui, FontType type)
+store_new_font (GtkComboBox *combo, KzPrefsFont *prefsui, FontType type)
 {
 	const gchar *lang, *new_font;
 	gchar **font = NULL;
 	GList *node;
 	FontPref *pref = NULL;
 
-	g_return_if_fail(GTK_ENTRY(entry));
+	g_return_if_fail(GTK_IS_COMBO_BOX(combo));
 
 	if (prefsui->freeze) return;
 
@@ -381,7 +360,7 @@ store_new_font (GtkEntry *entry, KzPrefsFont *prefsui, FontType type)
 	pref = node->data;
 	if (!pref) return;
 
-	new_font = gtk_entry_get_text(entry);
+	new_font = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(combo)->child));
 
 	switch (type) {
 	case FONT_SERIF:
@@ -417,7 +396,7 @@ store_new_font_size (GtkSpinButton *spin, KzPrefsFont *prefsui,
 	FontPref *pref = NULL;
 	gint size;
 
-	g_return_if_fail(GTK_SPIN_BUTTON(spin));
+	g_return_if_fail(GTK_IS_SPIN_BUTTON(spin));
 
 	if (prefsui->freeze) return;
 
@@ -451,23 +430,23 @@ store_new_font_size (GtkSpinButton *spin, KzPrefsFont *prefsui,
 
 
 static void
-cb_serif_entry_changed (GtkEntry *entry, KzPrefsFont *prefsui)
+cb_serif_entry_changed (GtkComboBox *combo, KzPrefsFont *prefsui)
 {
-	store_new_font (entry, prefsui, FONT_SERIF);
+	store_new_font (combo, prefsui, FONT_SERIF);
 }
 
 
 static void
-cb_sans_serif_entry_changed (GtkEntry *entry, KzPrefsFont *prefsui)
+cb_sans_serif_entry_changed (GtkComboBox *combo, KzPrefsFont *prefsui)
 {
-	store_new_font (entry, prefsui, FONT_SANS_SERIF);
+	store_new_font (combo, prefsui, FONT_SANS_SERIF);
 }
 
 
 static void
-cb_monospace_entry_changed (GtkEntry *entry, KzPrefsFont *prefsui)
+cb_monospace_entry_changed (GtkComboBox *combo, KzPrefsFont *prefsui)
 {
-	store_new_font (entry, prefsui, FONT_MONO);
+	store_new_font (combo, prefsui, FONT_MONO);
 }
 
 
@@ -497,7 +476,8 @@ prefs_font_create (void)
 {
 	KzPrefsFont *prefsui = g_new0(KzPrefsFont, 1);
 	GtkWidget *main_vbox, *vbox, *hbox;
-	GtkWidget *frame, *table, *label, *option_menu, *menu, *combo, *spin;
+	GtkWidget *frame, *table, *label, *option_menu, *combo, *spin;
+	gchar *str;
 
 	prefsui->prefs_list = NULL;
 	prefsui->freeze     = FALSE;
@@ -535,15 +515,13 @@ prefs_font_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	option_menu = gtk_option_menu_new();
-	prefsui->lang_option_menu = GTK_OPTION_MENU(option_menu);
+	option_menu = gtk_combo_box_new_text();
+	prefsui->lang_option_menu = GTK_COMBO_BOX(option_menu);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), option_menu);
 	gtk_box_pack_start(GTK_BOX(hbox), option_menu, FALSE, FALSE, 0);
 	gtk_widget_show(option_menu);
 
-	CREATE_MENU(menu, fonts_language, n_fonts_languages, title);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(option_menu), menu);
-	gtk_widget_show(menu);
+	GTKUTIL_CREATE_MENU(option_menu, fonts_language, n_fonts_languages, title);
 
 	g_signal_connect (G_OBJECT(option_menu), "changed",
 			  G_CALLBACK (cb_font_lang_changed), prefsui);
@@ -567,8 +545,8 @@ prefs_font_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	option_menu = gtk_option_menu_new();
-	prefsui->propotional_menu = GTK_OPTION_MENU(option_menu);
+	option_menu = gtk_combo_box_new_text();
+	prefsui->propotional_menu = GTK_COMBO_BOX(option_menu);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), option_menu);
 	gtk_table_attach(GTK_TABLE(table), option_menu,
 			 1, 2, 0, 1,
@@ -576,9 +554,7 @@ prefs_font_create (void)
 			 2, 2);
 	gtk_widget_show(option_menu);
 
-	CREATE_MENU(menu, font_styles, n_font_styles, title);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(option_menu), menu);
-	gtk_widget_show(menu);
+	GTKUTIL_CREATE_MENU(option_menu, font_styles, n_font_styles, title);
 
 	/* font size */
 	label = gtk_label_new_with_mnemonic(_("Si_ze:"));
@@ -614,11 +590,11 @@ prefs_font_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	combo = gtk_combo_new();
-	prefsui->serif_combo = GTK_COMBO(combo);
+	combo = gtk_combo_box_entry_new_text();
+	prefsui->serif_combo = GTK_COMBO_BOX(combo);
 	gtk_widget_set_size_request(combo, 90, -1);
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_COMBO(combo)->entry);
-	g_signal_connect (G_OBJECT(GTK_COMBO(combo)->entry), "changed",
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
+	g_signal_connect (G_OBJECT(combo), "changed",
 			  G_CALLBACK(cb_serif_entry_changed), prefsui);
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 1, 2,
@@ -640,11 +616,11 @@ prefs_font_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	combo = gtk_combo_new();
-	prefsui->sans_serif_combo = GTK_COMBO(combo);
+	combo = gtk_combo_box_entry_new_text();
+	prefsui->sans_serif_combo = GTK_COMBO_BOX(combo);
 	gtk_widget_set_size_request(combo, 90, -1);
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_COMBO(combo)->entry);
-	g_signal_connect (G_OBJECT(GTK_COMBO(combo)->entry), "changed",
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
+	g_signal_connect (G_OBJECT(combo), "changed",
 			  G_CALLBACK(cb_sans_serif_entry_changed), prefsui);
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 2, 3,
@@ -666,11 +642,11 @@ prefs_font_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	combo = gtk_combo_new();
-	prefsui->monospace_combo = GTK_COMBO(combo);
+	combo = gtk_combo_box_entry_new_text();
+	prefsui->monospace_combo = GTK_COMBO_BOX(combo);
 	gtk_widget_set_size_request(combo, 90, -1);
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_COMBO(combo)->entry);
-	g_signal_connect (G_OBJECT(GTK_COMBO(combo)->entry), "changed",
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
+	g_signal_connect (G_OBJECT(combo), "changed",
 			  G_CALLBACK(cb_monospace_entry_changed), prefsui);
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 3, 4,
@@ -723,12 +699,18 @@ prefs_font_create (void)
 
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
 
-	SET_DEFAULT_HISTORY(prefsui->propotional_menu,
-			    "font.default",
-			    font_styles, n_font_styles, style);
-	SET_DEFAULT_HISTORY(prefsui->lang_option_menu,
-			    "font.language.group",
-			    fonts_language, n_fonts_languages, code);
+	mozilla_prefs_get_string("font.default", &str);
+	GTKUTIL_SET_DEFAULT_HISTORY(prefsui->propotional_menu,
+			    	    str,
+			    	    font_styles, n_font_styles, style);
+	if (str)
+		g_free(str);
+	mozilla_prefs_get_string("font.language.group", &str);
+	GTKUTIL_SET_DEFAULT_HISTORY(prefsui->lang_option_menu,
+			    	    str,
+			    	    fonts_language, n_fonts_languages, code);
+	if (str)
+		g_free(str);
 	font_prefs_reset(prefsui);
 
 	return main_vbox;
@@ -740,7 +722,7 @@ static void
 apply_font_prefs (KzPrefsFont *prefsui)
 {
 	GList *node;
-	gint i;
+	guint i;
 
 	g_return_if_fail(prefsui);
 
@@ -799,11 +781,11 @@ apply_font_prefs (KzPrefsFont *prefsui)
 		}
 	}
 
-	i = gtk_option_menu_get_history(prefsui->propotional_menu);
+	i = gtk_combo_box_get_active(prefsui->propotional_menu);
 	if (i >= 0 && i < n_font_styles)
 		mozilla_prefs_set_string("font.default", font_styles[i].style);
 
-	i = gtk_option_menu_get_history(prefsui->lang_option_menu);
+	i = gtk_combo_box_get_active(prefsui->lang_option_menu);
 	if (i >= 0 && i < n_fonts_languages)
 		mozilla_prefs_set_string("font.language.group",
 					 fonts_language[i].code);
