@@ -22,9 +22,10 @@
 #include "prefs_history.h"
 
 #include <string.h>
+#include <glib/gi18n.h>
 #include "kazehakase.h"
-#include "utils/intl.h"
 #include "utils/gtk-utils.h"
+#include "utils/estsearch.h"
 
 
 #define DATA_KEY "KzPrefsHistory::info"
@@ -51,6 +52,8 @@ typedef struct _KzPrefsHistory
 	GtkWidget     *store_cache_check;
 	GtkWidget     *limit_days_check;
 	GtkWidget     *limit_days_spin;
+	GtkWidget     *optimize_label;
+	GtkWidget     *optimize_button;
 	GtkWidget     *max_results;
 	GtkWidget     *num_summary;
 	gboolean       changed;
@@ -81,6 +84,27 @@ cb_changed (GtkWidget *widget, KzPrefsHistory *prefsui)
 	prefsui->changed = TRUE;
 }
 
+static void
+cb_optimize_exit (GPid pid, gint status, gpointer data)
+{
+	g_spawn_close_pid(pid);
+
+	gtk_widget_set_sensitive(GTK_WIDGET(data), TRUE);
+}
+
+static void
+cb_optimize_button_clicked (GtkButton *button, KzPrefsHistory *prefsui)
+{
+	GPid pid;
+	
+	gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
+
+	pid = estsearch_optimize_index();
+	g_child_watch_add(pid,
+			  cb_optimize_exit,
+			  button);
+}
+
 
 static void
 prefs_history_destroy (gpointer data)
@@ -96,7 +120,7 @@ prefs_history_create (void)
 {
 	KzPrefsHistory *prefsui = g_new0(KzPrefsHistory, 1);
 	GtkWidget *main_vbox, *vbox, *hbox, *frame;
-	GtkWidget *label, *check, *spin;
+	GtkWidget *label, *check, *spin, *button;
 	GtkAdjustment *adj;
 	gboolean limit, store_cache = TRUE;
 	gint limit_days, max_results, num_summary;
@@ -130,10 +154,10 @@ prefs_history_create (void)
 	gtk_widget_show(frame);
 	gtk_widget_show(check);
 
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
-	gtk_container_add(GTK_CONTAINER(frame), hbox);
-	gtk_widget_show(hbox);
+	vbox = gtk_vbox_new(FALSE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
+	gtk_container_add(GTK_CONTAINER(frame), vbox);
+	gtk_widget_show(vbox);
 
 	limit = TRUE;
 	KZ_CONF_GET("History", "limit_cache", limit, BOOL);
@@ -141,6 +165,11 @@ prefs_history_create (void)
 	limit_days = 30;
 	KZ_CONF_GET("History", "limit_days", limit_days, INT);
 
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
+	gtk_container_add(GTK_CONTAINER(vbox), hbox);
+	gtk_widget_show(hbox);
+
 	check = gtk_check_button_new_with_mnemonic(_("_Limit days of keeping the history cache"));
 	prefsui->limit_days_check = check;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), limit);
@@ -160,6 +189,28 @@ prefs_history_create (void)
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(spin);
 
+	/*
+	 * optimize index
+	 */
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
+	gtk_container_add(GTK_CONTAINER(vbox), hbox);
+	gtk_widget_show(hbox);
+
+	prefsui->optimize_label = label
+		= gtk_label_new(_("Optimize history cache"));
+	gtk_widget_set_sensitive(label, store_cache);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
+	gtk_widget_show(label);
+
+	prefsui->optimize_button = button
+		= gtk_button_new_with_label (_("start"));
+	gtk_widget_set_sensitive(button, store_cache);
+	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 4);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(cb_optimize_button_clicked), prefsui);
+	gtk_widget_show(button);
+
 	/*
 	 * History Search
 	 */
