@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-downloader-sidebar.c,v 1.7 2004/09/30 00:06:07 ikezoe Exp $
+ *  $Id: kz-downloader-sidebar.c,v 1.8 2004/11/22 01:08:41 ikezoe Exp $
  */
 
 #include "kz-downloader-sidebar.h"
@@ -381,9 +381,9 @@ kz_downloader_sidebar_new (KzSidebar *sidebar)
 {
 	KzDownloaderSidebar *dsidebar;
 
-	dsidebar = KZ_DOWNLOADER_SIDEBAR(g_object_new(KZ_TYPE_DOWNLOADER_SIDEBAR,
-						      "sidebar", sidebar,
-						      NULL));
+	dsidebar = g_object_new(KZ_TYPE_DOWNLOADER_SIDEBAR,
+				"sidebar", sidebar,
+				NULL);
 
 	return GTK_WIDGET(dsidebar);
 }
