@@ -18,17 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 3S30, Boston, MA 02111-1307, USA.
  *
- * $Id: kz-dlist.c,v 1.2 2004/07/14 03:23:59 ikezoe Exp $
+ * $Id: kz-dlist.c,v 1.3 2004/09/30 00:06:08 ikezoe Exp $
  */
 
 #include "kz-dlist.h"
 
 #include <string.h>
 #include <stdlib.h>
+#include <glib/gi18n.h>
 
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
 
 enum {
 	AVAILABLE_LIST_UPDATED_SIGNAL,
@@ -773,7 +773,7 @@ cb_up_button_pressed (GtkButton *button, gpointer data)
 	gtk_tree_model_get_iter(model, &prev_iter, treepath);
 	gtk_tree_path_free(treepath);
 
-	gtkutil_list_store_swap(GTK_LIST_STORE(model), &iter, &prev_iter);
+	gtk_list_store_swap(GTK_LIST_STORE(model), &iter, &prev_iter);
 
 	kz_dlist_enabled_list_updated(dlist);
 }
@@ -799,7 +799,7 @@ cb_down_button_pressed (GtkButton *button, gpointer data)
 	success = gtk_tree_model_iter_next(model, &next_iter);
 	if (!success) return;
 
-	gtkutil_list_store_swap(GTK_LIST_STORE(model), &iter, &next_iter);
+	gtk_list_store_swap(GTK_LIST_STORE(model), &iter, &next_iter);
 
 	kz_dlist_enabled_list_updated(dlist);
 }
