@@ -25,7 +25,12 @@
 
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
+#include <glib/gi18n.h>
+
+enum {
+	CHANGED_POSITION,
+	LAST_SIGNAL
+};
 
 /* object class */
 static void kz_paned_class_init     (KzPanedClass   *klass);
@@ -61,6 +66,7 @@ static void kz_paned_set_divider_position (KzPaned *kzpaned);
 
 static GtkPanedClass *parent_class = NULL;
 
+static gint kz_paned_signals[LAST_SIGNAL] = {0};
  
 KZ_OBJECT_GET_TYPE(kz_paned, "KzPaned", KzPaned,
 		   kz_paned_class_init, kz_paned_init,
@@ -77,6 +83,18 @@ kz_paned_class_init (KzPanedClass *klass)
 
 	widget_class->size_request  = kz_paned_size_request;
 	widget_class->size_allocate = kz_paned_size_allocate;
+	
+	klass->changed_position = NULL;
+
+	kz_paned_signals[CHANGED_POSITION]
+		= g_signal_new ("changed_position",
+				G_TYPE_FROM_CLASS (klass),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (KzPanedClass, changed_position),
+				NULL, NULL,
+				g_cclosure_marshal_VOID__INT,
+				G_TYPE_NONE, 1,
+				G_TYPE_INT);
 }
 
 
@@ -95,7 +113,7 @@ kz_paned_new (void)
 {
 	KzPaned *kzpaned;
 
-	kzpaned = KZ_PANED(g_object_new (KZ_TYPE_PANED, NULL));
+	kzpaned = g_object_new (KZ_TYPE_PANED, NULL);
 
 	return GTK_WIDGET (kzpaned);
 }
@@ -146,6 +164,11 @@ kz_paned_set_position(KzPaned *kzpaned, GtkPositionType position)
 		break;
 	}	
 	gtk_widget_queue_resize(GTK_WIDGET(kzpaned));
+
+	g_signal_emit(G_OBJECT(kzpaned),
+		      kz_paned_signals[CHANGED_POSITION],
+		      0,
+		      position);
 }
 
 
